/* GXmlElement.c generated by valac 0.34.6, the Vala compiler
 * generated from GXmlElement.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 2; tab-width: 2 -*- */
/* GElement.vala
 *
 * Copyright (C) 2016  Daniel Espinosa <esodan@gmail.com>
 * Copyright (C) 2016  Yannick Inizan <inizan.yannick@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 *      Yannick Inizan <inizan.yannick@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>
#include <libxml/tree.h>
#include <float.h>
#include <math.h>
#include <libxml/parser.h>
#include <glib/gi18n-lib.h>
#include <libxml/xpath.h>


#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_GNODE (gxml_gnode_get_type ())
#define GXML_GNODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GNODE, GXmlGNode))
#define GXML_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GNODE, GXmlGNodeClass))
#define GXML_IS_GNODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GNODE))
#define GXML_IS_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GNODE))
#define GXML_GNODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GNODE, GXmlGNodeClass))

typedef struct _GXmlGNode GXmlGNode;
typedef struct _GXmlGNodeClass GXmlGNodeClass;
typedef struct _GXmlGNodePrivate GXmlGNodePrivate;

#define GXML_TYPE_GDOCUMENT (gxml_gdocument_get_type ())
#define GXML_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocument))
#define GXML_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))
#define GXML_IS_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOCUMENT))
#define GXML_IS_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOCUMENT))
#define GXML_GDOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))

typedef struct _GXmlGDocument GXmlGDocument;
typedef struct _GXmlGDocumentClass GXmlGDocumentClass;

#define GXML_TYPE_GCHILD_NODE (gxml_gchild_node_get_type ())
#define GXML_GCHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GCHILD_NODE, GXmlGChildNode))
#define GXML_GCHILD_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GCHILD_NODE, GXmlGChildNodeClass))
#define GXML_IS_GCHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GCHILD_NODE))
#define GXML_IS_GCHILD_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GCHILD_NODE))
#define GXML_GCHILD_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GCHILD_NODE, GXmlGChildNodeClass))

typedef struct _GXmlGChildNode GXmlGChildNode;
typedef struct _GXmlGChildNodeClass GXmlGChildNodeClass;
typedef struct _GXmlGChildNodePrivate GXmlGChildNodePrivate;

#define GXML_TYPE_GNON_DOCUMENT_CHILD_NODE (gxml_gnon_document_child_node_get_type ())
#define GXML_GNON_DOCUMENT_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE, GXmlGNonDocumentChildNode))
#define GXML_GNON_DOCUMENT_CHILD_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE, GXmlGNonDocumentChildNodeClass))
#define GXML_IS_GNON_DOCUMENT_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE))
#define GXML_IS_GNON_DOCUMENT_CHILD_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE))
#define GXML_GNON_DOCUMENT_CHILD_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE, GXmlGNonDocumentChildNodeClass))

typedef struct _GXmlGNonDocumentChildNode GXmlGNonDocumentChildNode;
typedef struct _GXmlGNonDocumentChildNodeClass GXmlGNonDocumentChildNodeClass;
typedef struct _GXmlGNonDocumentChildNodePrivate GXmlGNonDocumentChildNodePrivate;

#define GXML_TYPE_ELEMENT (gxml_element_get_type ())
#define GXML_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT, GXmlElement))
#define GXML_IS_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT))
#define GXML_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_ELEMENT, GXmlElementIface))

typedef struct _GXmlElement GXmlElement;
typedef struct _GXmlElementIface GXmlElementIface;

#define GXML_TYPE_XPATH_CONTEXT (gxml_xpath_context_get_type ())
#define GXML_XPATH_CONTEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_XPATH_CONTEXT, GXmlXPathContext))
#define GXML_IS_XPATH_CONTEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_XPATH_CONTEXT))
#define GXML_XPATH_CONTEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_XPATH_CONTEXT, GXmlXPathContextIface))

typedef struct _GXmlXPathContext GXmlXPathContext;
typedef struct _GXmlXPathContextIface GXmlXPathContextIface;

#define GXML_TYPE_XPATH_OBJECT (gxml_xpath_object_get_type ())
#define GXML_XPATH_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_XPATH_OBJECT, GXmlXPathObject))
#define GXML_IS_XPATH_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_XPATH_OBJECT))
#define GXML_XPATH_OBJECT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_XPATH_OBJECT, GXmlXPathObjectIface))

typedef struct _GXmlXPathObject GXmlXPathObject;
typedef struct _GXmlXPathObjectIface GXmlXPathObjectIface;

#define GXML_TYPE_XPATH_OBJECT_TYPE (gxml_xpath_object_type_get_type ())

#define GXML_TYPE_GELEMENT (gxml_gelement_get_type ())
#define GXML_GELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GELEMENT, GXmlGElement))
#define GXML_GELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GELEMENT, GXmlGElementClass))
#define GXML_IS_GELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GELEMENT))
#define GXML_IS_GELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GELEMENT))
#define GXML_GELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GELEMENT, GXmlGElementClass))

typedef struct _GXmlGElement GXmlGElement;
typedef struct _GXmlGElementClass GXmlGElementClass;
typedef struct _GXmlGElementPrivate GXmlGElementPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

#define GXML_TYPE_GATTRIBUTE (gxml_gattribute_get_type ())
#define GXML_GATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GATTRIBUTE, GXmlGAttribute))
#define GXML_GATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GATTRIBUTE, GXmlGAttributeClass))
#define GXML_IS_GATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GATTRIBUTE))
#define GXML_IS_GATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GATTRIBUTE))
#define GXML_GATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GATTRIBUTE, GXmlGAttributeClass))

typedef struct _GXmlGAttribute GXmlGAttribute;
typedef struct _GXmlGAttributeClass GXmlGAttributeClass;
#define _xmlBufferFree0(var) ((var == NULL) ? NULL : (var = (xmlBufferFree (var), NULL)))

#define GXML_TYPE_GDOM_HTML_COLLECTION (gxml_gdom_html_collection_get_type ())
#define GXML_GDOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollection))
#define GXML_GDOM_HTML_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollectionClass))
#define GXML_IS_GDOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_HTML_COLLECTION))
#define GXML_IS_GDOM_HTML_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_HTML_COLLECTION))
#define GXML_GDOM_HTML_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_HTML_COLLECTION, GXmlGDomHTMLCollectionClass))

typedef struct _GXmlGDomHTMLCollection GXmlGDomHTMLCollection;
typedef struct _GXmlGDomHTMLCollectionClass GXmlGDomHTMLCollectionClass;
typedef struct _Block1Data Block1Data;
#define _xmlXPathFreeContext0(var) ((var == NULL) ? NULL : (var = (xmlXPathFreeContext (var), NULL)))

#define GXML_TYPE_GX_PATH_OBJECT (gxml_gx_path_object_get_type ())
#define GXML_GX_PATH_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GX_PATH_OBJECT, GXmlGXPathObject))
#define GXML_GX_PATH_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GX_PATH_OBJECT, GXmlGXPathObjectClass))
#define GXML_IS_GX_PATH_OBJECT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GX_PATH_OBJECT))
#define GXML_IS_GX_PATH_OBJECT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GX_PATH_OBJECT))
#define GXML_GX_PATH_OBJECT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GX_PATH_OBJECT, GXmlGXPathObjectClass))

typedef struct _GXmlGXPathObject GXmlGXPathObject;
typedef struct _GXmlGXPathObjectClass GXmlGXPathObjectClass;

#define GXML_TYPE_GDOM_TOKEN_LIST (gxml_gdom_token_list_get_type ())
#define GXML_GDOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOM_TOKEN_LIST, GXmlGDomTokenList))
#define GXML_GDOM_TOKEN_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOM_TOKEN_LIST, GXmlGDomTokenListClass))
#define GXML_IS_GDOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOM_TOKEN_LIST))
#define GXML_IS_GDOM_TOKEN_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOM_TOKEN_LIST))
#define GXML_GDOM_TOKEN_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOM_TOKEN_LIST, GXmlGDomTokenListClass))

typedef struct _GXmlGDomTokenList GXmlGDomTokenList;
typedef struct _GXmlGDomTokenListClass GXmlGDomTokenListClass;

typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, int* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parentNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*firstChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*lastChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlGNode {
	GObject parent_instance;
	GXmlGNodePrivate * priv;
	GXmlGDocument* _doc;
	xmlNode* _node;
	gchar* _base_uri;
};

struct _GXmlGNodeClass {
	GObjectClass parent_class;
	gboolean (*set_namespace) (GXmlGNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*to_string) (GXmlGNode* self);
	GeeMap* (*get_attrs) (GXmlGNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlGNode* self);
	GeeList* (*get_namespaces) (GXmlGNode* self);
	GXmlDocument* (*get_document) (GXmlGNode* self);
	GXmlNode* (*get_parent) (GXmlGNode* self);
	GXmlNodeType (*get_type_node) (GXmlGNode* self);
	gchar* (*get_name) (GXmlGNode* self);
	gchar* (*get_value) (GXmlGNode* self);
	void (*set_value) (GXmlGNode* self, const gchar* value);
};

struct _GXmlGChildNode {
	GXmlGNode parent_instance;
	GXmlGChildNodePrivate * priv;
};

struct _GXmlGChildNodeClass {
	GXmlGNodeClass parent_class;
};

struct _GXmlGNonDocumentChildNode {
	GXmlGChildNode parent_instance;
	GXmlGNonDocumentChildNodePrivate * priv;
};

struct _GXmlGNonDocumentChildNodeClass {
	GXmlGChildNodeClass parent_class;
};

struct _GXmlElementIface {
	GTypeInterface parent_iface;
	void (*normalize) (GXmlElement* self);
	void (*set_attr) (GXmlElement* self, const gchar* name, const gchar* value);
	GXmlNode* (*get_attr) (GXmlElement* self, const gchar* name);
	void (*remove_attr) (GXmlElement* self, const gchar* name);
	void (*remove_ns_attr) (GXmlElement* self, const gchar* name, const gchar* uri);
	void (*set_ns_attr) (GXmlElement* self, const gchar* ns, const gchar* name, const gchar* value);
	GXmlNode* (*get_ns_attr) (GXmlElement* self, const gchar* name, const gchar* uri);
	gchar* (*get_tag_name) (GXmlElement* self);
	gchar* (*get_content) (GXmlElement* self);
	void (*set_content) (GXmlElement* self, const gchar* value);
};

typedef enum  {
	GXML_XPATH_OBJECT_TYPE_UNDEFINED,
	GXML_XPATH_OBJECT_TYPE_NODESET,
	GXML_XPATH_OBJECT_TYPE_BOOLEAN,
	GXML_XPATH_OBJECT_TYPE_NUMBER,
	GXML_XPATH_OBJECT_TYPE_STRING,
	GXML_XPATH_OBJECT_TYPE_POINT,
	GXML_XPATH_OBJECT_TYPE_RANGE,
	GXML_XPATH_OBJECT_TYPE_LOCATIONSET,
	GXML_XPATH_OBJECT_TYPE_USERS,
	GXML_XPATH_OBJECT_TYPE_XSLT_TREE
} GXmlXPathObjectType;

struct _GXmlXPathObjectIface {
	GTypeInterface parent_iface;
	GXmlXPathObjectType (*get_object_type) (GXmlXPathObject* self);
	gboolean (*get_boolean_value) (GXmlXPathObject* self);
	const gchar* (*get_string_value) (GXmlXPathObject* self);
	gdouble (*get_number_value) (GXmlXPathObject* self);
	GXmlDomHTMLCollection* (*get_nodeset) (GXmlXPathObject* self);
};

typedef enum  {
	GXML_XPATH_ERROR_EXPRESSION_OK,
	GXML_XPATH_ERROR_NUMBER_ERROR,
	GXML_XPATH_ERROR_UNFINISHED_LITERAL_ERROR,
	GXML_XPATH_ERROR_START_LITERAL_ERROR,
	GXML_XPATH_ERROR_VARIABLE_REF_ERROR,
	GXML_XPATH_ERROR_UNDEF_VARIABLE_ERROR,
	GXML_XPATH_ERROR_INVALID_PREDICATE_ERROR,
	GXML_XPATH_ERROR_EXPR_ERROR,
	GXML_XPATH_ERROR_UNCLOSED_ERROR,
	GXML_XPATH_ERROR_UNKNOWN_FUNC_ERROR,
	GXML_XPATH_ERROR_INVALID_OPERAND,
	GXML_XPATH_ERROR_INVALID_TYPE,
	GXML_XPATH_ERROR_INVALID_ARITY,
	GXML_XPATH_ERROR_INVALID_CTXT_SIZE,
	GXML_XPATH_ERROR_INVALID_CTXT_POSITION,
	GXML_XPATH_ERROR_MEMORY_ERROR,
	GXML_XPATH_ERROR_XPTR_SYNTAX_ERROR,
	GXML_XPATH_ERROR_XPTR_RESOURCE_ERROR,
	GXML_XPATH_ERROR_XPTR_SUB_RESOURCE_ERROR,
	GXML_XPATH_ERROR_UNDEF_PREFIX_ERROR,
	GXML_XPATH_ERROR_ENCODING_ERROR,
	GXML_XPATH_ERROR_INVALID_CHAR_ERROR,
	GXML_XPATH_ERROR_INVALID_CTXT
} GXmlXPathError;
#define GXML_XPATH_ERROR gxml_xpath_error_quark ()
struct _GXmlXPathContextIface {
	GTypeInterface parent_iface;
	GXmlXPathObject* (*evaluate) (GXmlXPathContext* self, const gchar* expression, GeeList* resolver, GError** error);
};

struct _GXmlGElement {
	GXmlGNonDocumentChildNode parent_instance;
	GXmlGElementPrivate * priv;
};

struct _GXmlGElementClass {
	GXmlGNonDocumentChildNodeClass parent_class;
};

typedef enum  {
	GXML_DOM_ERROR_INDEX_SIZE_ERROR = 1,
	GXML_DOM_ERROR_DOMSTRING_SIZE_ERROR,
	GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR,
	GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR,
	GXML_DOM_ERROR_INVALID_CHARACTER_ERROR,
	GXML_DOM_ERROR_NO_DATA_ALLOWED_ERROR,
	GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR,
	GXML_DOM_ERROR_NOT_FOUND_ERROR,
	GXML_DOM_ERROR_NOT_SUPPORTED_ERROR,
	GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR,
	GXML_DOM_ERROR_INVALID_STATE_ERROR,
	GXML_DOM_ERROR_SYNTAX_ERROR,
	GXML_DOM_ERROR_INVALID_MODIFICATION_ERROR,
	GXML_DOM_ERROR_NAMESPACE_ERROR,
	GXML_DOM_ERROR_INVALID_ACCESS_ERROR,
	GXML_DOM_ERROR_VALIDATION_ERROR,
	GXML_DOM_ERROR_TYPE_MISMATCH_ERROR,
	GXML_DOM_ERROR_SECURITY_ERROR,
	GXML_DOM_ERROR_NETWORK_ERROR,
	GXML_DOM_ERROR_ABORT_ERROR,
	GXML_DOM_ERROR_URL_MISMATCH_ERROR,
	GXML_DOM_ERROR_QUOTA_EXCEEDED_ERROR,
	GXML_DOM_ERROR_TIME_OUT_ERROR,
	GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR,
	GXML_DOM_ERROR_DATA_CLONE_ERROR
} GXmlDomError;
#define GXML_DOM_ERROR gxml_dom_error_quark ()
struct _Block1Data {
	int _ref_count_;
	GXmlGElement* self;
	xmlXPathContext* context;
};


static gpointer gxml_gelement_parent_class = NULL;
static GXmlDomParentNodeIface* gxml_gelement_gxml_dom_parent_node_parent_iface = NULL;
static GXmlDomElementIface* gxml_gelement_gxml_dom_element_parent_iface = NULL;
static GXmlElementIface* gxml_gelement_gxml_element_parent_iface = NULL;
static GXmlXPathContextIface* gxml_gelement_gxml_xpath_context_parent_iface = NULL;

GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_gnode_get_type (void) G_GNUC_CONST;
GType gxml_gdocument_get_type (void) G_GNUC_CONST;
GType gxml_gchild_node_get_type (void) G_GNUC_CONST;
GType gxml_gnon_document_child_node_get_type (void) G_GNUC_CONST;
GType gxml_element_get_type (void) G_GNUC_CONST;
GType gxml_xpath_object_type_get_type (void) G_GNUC_CONST;
GType gxml_xpath_object_get_type (void) G_GNUC_CONST;
GQuark gxml_xpath_error_quark (void);
GType gxml_xpath_context_get_type (void) G_GNUC_CONST;
GType gxml_gelement_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GELEMENT_DUMMY_PROPERTY,
	GXML_GELEMENT_VALUE,
	GXML_GELEMENT_CONTENT,
	GXML_GELEMENT_TAG_NAME,
	GXML_GELEMENT_NAMESPACE_URI,
	GXML_GELEMENT_PREFIX,
	GXML_GELEMENT_LOCAL_NAME,
	GXML_GELEMENT_ID,
	GXML_GELEMENT_CLASS_NAME,
	GXML_GELEMENT_CLASS_LIST,
	GXML_GELEMENT_ATTRIBUTES,
	GXML_GELEMENT_CHILDREN,
	GXML_GELEMENT_FIRST_ELEMENT_CHILD,
	GXML_GELEMENT_LAST_ELEMENT_CHILD,
	GXML_GELEMENT_CHILD_ELEMENT_COUNT
};
GXmlGElement* gxml_gelement_new (GXmlGDocument* doc, xmlNode* node);
GXmlGElement* gxml_gelement_construct (GType object_type, GXmlGDocument* doc, xmlNode* node);
GXmlGNonDocumentChildNode* gxml_gnon_document_child_node_new (void);
GXmlGNonDocumentChildNode* gxml_gnon_document_child_node_construct (GType object_type);
static void gxml_gelement_real_set_attr (GXmlElement* base, const gchar* aname, const gchar* avalue);
static GXmlNode* gxml_gelement_real_get_attr (GXmlElement* base, const gchar* name);
GXmlGAttribute* gxml_gattribute_new (GXmlGDocument* doc, xmlAttr* node);
GXmlGAttribute* gxml_gattribute_construct (GType object_type, GXmlGDocument* doc, xmlAttr* node);
GType gxml_gattribute_get_type (void) G_GNUC_CONST;
static void gxml_gelement_real_set_ns_attr (GXmlElement* base, const gchar* ns, const gchar* aname, const gchar* value);
static GXmlNode* gxml_gelement_real_get_ns_attr (GXmlElement* base, const gchar* name, const gchar* uri);
static void gxml_gelement_real_normalize (GXmlElement* base);
static void gxml_gelement_real_remove_attr (GXmlElement* base, const gchar* name);
static void gxml_gelement_real_remove_ns_attr (GXmlElement* base, const gchar* name, const gchar* uri);
static gchar* gxml_gelement_real_to_string (GXmlGNode* base);
static gchar* gxml_gelement_real_get_attribute (GXmlDomElement* base, const gchar* name);
GeeMap* gxml_gnode_get_attrs (GXmlGNode* self);
gchar* gxml_node_get_value (GXmlNode* self);
static gchar* gxml_gelement_real_get_attribute_ns (GXmlDomElement* base, const gchar* namespace, const gchar* local_name);
GXmlNode* gxml_element_get_ns_attr (GXmlElement* self, const gchar* name, const gchar* uri);
static void gxml_gelement_real_set_attribute (GXmlDomElement* base, const gchar* name, const gchar* value, GError** error);
void gxml_element_set_attr (GXmlElement* self, const gchar* name, const gchar* value);
static void gxml_gelement_real_set_attribute_ns (GXmlDomElement* base, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
void gxml_element_set_ns_attr (GXmlElement* self, const gchar* ns, const gchar* name, const gchar* value);
static void gxml_gelement_real_remove_attribute (GXmlDomElement* base, const gchar* name);
void gxml_element_remove_attr (GXmlElement* self, const gchar* name);
static void gxml_gelement_real_remove_attribute_ns (GXmlDomElement* base, const gchar* namespace, const gchar* local_name);
void gxml_element_remove_ns_attr (GXmlElement* self, const gchar* name, const gchar* uri);
static gboolean gxml_gelement_real_has_attribute (GXmlDomElement* base, const gchar* name);
static gboolean gxml_gelement_real_has_attribute_ns (GXmlDomElement* base, const gchar* namespace, const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gelement_real_get_elements_by_tag_name (GXmlDomElement* base, const gchar* local_name);
GType gxml_gdom_html_collection_get_type (void) G_GNUC_CONST;
GXmlGDomHTMLCollection* gxml_gdom_html_collection_new (void);
GXmlGDomHTMLCollection* gxml_gdom_html_collection_construct (GType object_type);
GXmlDomHTMLCollection* gxml_dom_parent_node_get_children (GXmlDomParentNode* self);
gchar* gxml_dom_node_get_node_name (GXmlDomNode* self);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_tag_name (GXmlDomElement* self, const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gelement_real_get_elements_by_tag_name_ns (GXmlDomElement* base, const gchar* namespace, const gchar* local_name);
gchar* gxml_dom_element_get_namespace_uri (GXmlDomElement* self);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_tag_name_ns (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
static GXmlDomHTMLCollection* gxml_gelement_real_get_elements_by_class_name (GXmlDomElement* base, const gchar* class_names);
static void _vala_array_add6 (gchar*** array, int* length, int* size, gchar* value);
gchar* gxml_dom_element_get_attribute (GXmlDomElement* self, const gchar* name);
static void _vala_array_add7 (gchar*** array, int* length, int* size, gchar* value);
GXmlDomHTMLCollection* gxml_dom_element_get_elements_by_class_name (GXmlDomElement* self, const gchar* class_names);
static GXmlDomElement* gxml_gelement_real_query_selector (GXmlDomParentNode* base, const gchar* selectors, GError** error);
GQuark gxml_dom_error_quark (void);
static GXmlDomNodeList* gxml_gelement_real_query_selector_all (GXmlDomParentNode* base, const gchar* selectors, GError** error);
static GXmlXPathObject* gxml_gelement_real_evaluate (GXmlXPathContext* base, const gchar* expression, GeeList* resolver, GError** error);
static Block1Data* block1_data_ref (Block1Data* _data1_);
static void block1_data_unref (void * _userdata_);
gchar* gxml_node_to_string (GXmlNode* self);
GXmlGDocument* gxml_gdocument_new_from_doc (xmlDoc* doc);
GXmlGDocument* gxml_gdocument_construct_from_doc (GType object_type, xmlDoc* doc);
static gboolean ___lambda4_ (Block1Data* _data1_, GXmlNamespace* ns);
gchar* gxml_namespace_get_prefix (GXmlNamespace* self);
gchar* gxml_namespace_get_uri (GXmlNamespace* self);
static gboolean ____lambda4__gee_forall_func (gpointer g, gpointer self);
GXmlGXPathObject* gxml_gx_path_object_new (GXmlGDocument* document, xmlXPathObject* pointer);
GXmlGXPathObject* gxml_gx_path_object_construct (GType object_type, GXmlGDocument* document, xmlXPathObject* pointer);
GType gxml_gx_path_object_get_type (void) G_GNUC_CONST;
gchar* gxml_element_get_content (GXmlElement* self);
void gxml_element_set_content (GXmlElement* self, const gchar* value);
gchar* gxml_gnode_get_name (GXmlGNode* self);
void gxml_node_set_value (GXmlNode* self, const gchar* value);
GXmlGDomTokenList* gxml_gdom_token_list_new (GXmlDomElement* e, const gchar* attr);
GXmlGDomTokenList* gxml_gdom_token_list_construct (GType object_type, GXmlDomElement* e, const gchar* attr);
GType gxml_gdom_token_list_get_type (void) G_GNUC_CONST;
GXmlDomElementList* gxml_dom_element_list_new (void);
GXmlDomElementList* gxml_dom_element_list_construct (GType object_type);
GXmlDomNodeList* gxml_dom_node_get_child_nodes (GXmlDomNode* self);
gchar* gxml_gnode_get_value (GXmlGNode* self);
gchar* gxml_dom_element_get_tag_name (GXmlDomElement* self);
gchar* gxml_dom_element_get_prefix (GXmlDomElement* self);
gchar* gxml_dom_element_get_local_name (GXmlDomElement* self);
gchar* gxml_dom_element_get_id (GXmlDomElement* self);
gchar* gxml_dom_element_get_class_name (GXmlDomElement* self);
GXmlDomTokenList* gxml_dom_element_get_class_list (GXmlDomElement* self);
GXmlDomNamedNodeMap* gxml_dom_element_get_attributes (GXmlDomElement* self);
GXmlDomElement* gxml_dom_parent_node_get_first_element_child (GXmlDomParentNode* self);
GXmlDomElement* gxml_dom_parent_node_get_last_element_child (GXmlDomParentNode* self);
gint gxml_dom_parent_node_get_child_element_count (GXmlDomParentNode* self);
static void _vala_gxml_gelement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void gxml_gnode_set_value (GXmlGNode* self, const gchar* value);
void gxml_dom_element_set_id (GXmlDomElement* self, const gchar* value);
void gxml_dom_element_set_class_name (GXmlDomElement* self, const gchar* value);
static void _vala_gxml_gelement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


GXmlGElement* gxml_gelement_construct (GType object_type, GXmlGDocument* doc, xmlNode* node) {
	GXmlGElement * self = NULL;
	xmlNode* _tmp0_ = NULL;
	GXmlGDocument* _tmp1_ = NULL;
	GXmlGDocument* _tmp2_ = NULL;
	g_return_val_if_fail (doc != NULL, NULL);
	self = (GXmlGElement*) gxml_gnon_document_child_node_construct (object_type);
	_tmp0_ = node;
	((GXmlGNode*) self)->_node = _tmp0_;
	_tmp1_ = doc;
	_tmp2_ = _g_object_ref0 (_tmp1_);
	_g_object_unref0 (((GXmlGNode*) self)->_doc);
	((GXmlGNode*) self)->_doc = _tmp2_;
	return self;
}


GXmlGElement* gxml_gelement_new (GXmlGDocument* doc, xmlNode* node) {
	return gxml_gelement_construct (GXML_TYPE_GELEMENT, doc, node);
}


static gboolean string_contains (const gchar* self, const gchar* needle) {
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	g_return_val_if_fail (self != NULL, FALSE);
	g_return_val_if_fail (needle != NULL, FALSE);
	_tmp0_ = needle;
	_tmp1_ = strstr ((gchar*) self, (gchar*) _tmp0_);
	result = _tmp1_ != NULL;
	return result;
}


static void gxml_gelement_real_set_attr (GXmlElement* base, const gchar* aname, const gchar* avalue) {
	GXmlGElement * self;
	xmlNode* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gboolean _tmp2_ = FALSE;
	xmlNode* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	const gchar* _tmp5_ = NULL;
	self = (GXmlGElement*) base;
	g_return_if_fail (aname != NULL);
	g_return_if_fail (avalue != NULL);
	_tmp0_ = ((GXmlGNode*) self)->_node;
	if (_tmp0_ == NULL) {
		return;
	}
	_tmp1_ = aname;
	_tmp2_ = string_contains (_tmp1_, ":");
	if (_tmp2_) {
		return;
	}
	_tmp3_ = ((GXmlGNode*) self)->_node;
	_tmp4_ = aname;
	_tmp5_ = avalue;
	xmlSetProp (_tmp3_, (xmlChar*) _tmp4_, (xmlChar*) _tmp5_);
}


static GXmlNode* gxml_gelement_real_get_attr (GXmlElement* base, const gchar* name) {
	GXmlGElement * self;
	GXmlNode* result = NULL;
	xmlNode* _tmp0_ = NULL;
	gchar* prefix = NULL;
	gchar* n = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	const gchar* _tmp15_ = NULL;
	xmlAttr* p = NULL;
	xmlNode* _tmp31_ = NULL;
	const gchar* _tmp32_ = NULL;
	xmlAttr* _tmp33_ = NULL;
	xmlAttr* _tmp34_ = NULL;
	GXmlGDocument* _tmp35_ = NULL;
	xmlAttr* _tmp36_ = NULL;
	GXmlGAttribute* _tmp37_ = NULL;
	self = (GXmlGElement*) base;
	g_return_val_if_fail (name != NULL, NULL);
	_tmp0_ = ((GXmlGNode*) self)->_node;
	if (_tmp0_ == NULL) {
		result = NULL;
		return result;
	}
	prefix = NULL;
	_tmp1_ = name;
	_tmp2_ = g_strdup (_tmp1_);
	n = _tmp2_;
	_tmp3_ = name;
	_tmp4_ = string_contains (_tmp3_, ":");
	if (_tmp4_) {
		gchar** pp = NULL;
		const gchar* _tmp5_ = NULL;
		gchar** _tmp6_ = NULL;
		gchar** _tmp7_ = NULL;
		gint pp_length1 = 0;
		gint _pp_size_ = 0;
		gchar** _tmp8_ = NULL;
		gint _tmp8__length1 = 0;
		gchar** _tmp9_ = NULL;
		gint _tmp9__length1 = 0;
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar** _tmp12_ = NULL;
		gint _tmp12__length1 = 0;
		const gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		_tmp5_ = name;
		_tmp7_ = _tmp6_ = g_strsplit (_tmp5_, ":", 0);
		pp = _tmp7_;
		pp_length1 = _vala_array_length (_tmp6_);
		_pp_size_ = pp_length1;
		_tmp8_ = pp;
		_tmp8__length1 = pp_length1;
		if (_tmp8__length1 != 2) {
			result = NULL;
			pp = (_vala_array_free (pp, pp_length1, (GDestroyNotify) g_free), NULL);
			_g_free0 (n);
			_g_free0 (prefix);
			return result;
		}
		_tmp9_ = pp;
		_tmp9__length1 = pp_length1;
		_tmp10_ = _tmp9_[0];
		_tmp11_ = g_strdup (_tmp10_);
		_g_free0 (prefix);
		prefix = _tmp11_;
		_tmp12_ = pp;
		_tmp12__length1 = pp_length1;
		_tmp13_ = _tmp12_[1];
		_tmp14_ = g_strdup (_tmp13_);
		_g_free0 (n);
		n = _tmp14_;
		pp = (_vala_array_free (pp, pp_length1, (GDestroyNotify) g_free), NULL);
	}
	_tmp15_ = prefix;
	if (_tmp15_ != NULL) {
		xmlNs* ns = NULL;
		xmlNode* _tmp16_ = NULL;
		xmlDoc* _tmp17_ = NULL;
		xmlNode* _tmp18_ = NULL;
		const gchar* _tmp19_ = NULL;
		xmlNs* _tmp20_ = NULL;
		xmlNs* _tmp21_ = NULL;
		xmlAttr* nsa = NULL;
		xmlNode* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
		xmlNs* _tmp24_ = NULL;
		const gchar* _tmp25_ = NULL;
		xmlAttr* _tmp26_ = NULL;
		xmlAttr* _tmp27_ = NULL;
		GXmlGDocument* _tmp28_ = NULL;
		xmlAttr* _tmp29_ = NULL;
		GXmlGAttribute* _tmp30_ = NULL;
		_tmp16_ = ((GXmlGNode*) self)->_node;
		_tmp17_ = _tmp16_->doc;
		_tmp18_ = ((GXmlGNode*) self)->_node;
		_tmp19_ = prefix;
		_tmp20_ = xmlSearchNs (_tmp17_, _tmp18_, _tmp19_);
		ns = _tmp20_;
		_tmp21_ = ns;
		if (_tmp21_ == NULL) {
			result = NULL;
			_g_free0 (n);
			_g_free0 (prefix);
			return result;
		}
		_tmp22_ = ((GXmlGNode*) self)->_node;
		_tmp23_ = n;
		_tmp24_ = ns;
		_tmp25_ = _tmp24_->href;
		_tmp26_ = xmlHasNsProp (_tmp22_, (xmlChar*) _tmp23_, (xmlChar*) _tmp25_);
		nsa = _tmp26_;
		_tmp27_ = nsa;
		if (_tmp27_ == NULL) {
			result = NULL;
			_g_free0 (n);
			_g_free0 (prefix);
			return result;
		}
		_tmp28_ = ((GXmlGNode*) self)->_doc;
		_tmp29_ = nsa;
		_tmp30_ = gxml_gattribute_new (_tmp28_, _tmp29_);
		result = (GXmlNode*) _tmp30_;
		_g_free0 (n);
		_g_free0 (prefix);
		return result;
	}
	_tmp31_ = ((GXmlGNode*) self)->_node;
	_tmp32_ = n;
	_tmp33_ = xmlHasProp (_tmp31_, (xmlChar*) _tmp32_);
	p = _tmp33_;
	_tmp34_ = p;
	if (_tmp34_ == NULL) {
		result = NULL;
		_g_free0 (n);
		_g_free0 (prefix);
		return result;
	}
	_tmp35_ = ((GXmlGNode*) self)->_doc;
	_tmp36_ = p;
	_tmp37_ = gxml_gattribute_new (_tmp35_, _tmp36_);
	result = (GXmlNode*) _tmp37_;
	_g_free0 (n);
	_g_free0 (prefix);
	return result;
}


static void gxml_gelement_real_set_ns_attr (GXmlElement* base, const gchar* ns, const gchar* aname, const gchar* value) {
	GXmlGElement * self;
	xmlNode* _tmp0_ = NULL;
	gchar* prefix = NULL;
	gchar* qname = NULL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	xmlNs* ins = NULL;
	xmlNode* _tmp15_ = NULL;
	xmlDoc* _tmp16_ = NULL;
	xmlNode* _tmp17_ = NULL;
	const gchar* _tmp18_ = NULL;
	xmlNs* _tmp19_ = NULL;
	xmlNs* _tmp20_ = NULL;
	xmlNs* nns = NULL;
	xmlNode* _tmp25_ = NULL;
	const gchar* _tmp26_ = NULL;
	const gchar* _tmp27_ = NULL;
	xmlNs* _tmp28_ = NULL;
	xmlNs* _tmp29_ = NULL;
	self = (GXmlGElement*) base;
	g_return_if_fail (ns != NULL);
	g_return_if_fail (aname != NULL);
	g_return_if_fail (value != NULL);
	_tmp0_ = ((GXmlGNode*) self)->_node;
	if (_tmp0_ == NULL) {
		return;
	}
	prefix = NULL;
	_tmp1_ = aname;
	_tmp2_ = g_strdup (_tmp1_);
	qname = _tmp2_;
	_tmp3_ = aname;
	_tmp4_ = string_contains (_tmp3_, ":");
	if (_tmp4_) {
		gchar** s = NULL;
		const gchar* _tmp5_ = NULL;
		gchar** _tmp6_ = NULL;
		gchar** _tmp7_ = NULL;
		gint s_length1 = 0;
		gint _s_size_ = 0;
		gchar** _tmp8_ = NULL;
		gint _tmp8__length1 = 0;
		gchar** _tmp9_ = NULL;
		gint _tmp9__length1 = 0;
		const gchar* _tmp10_ = NULL;
		gchar* _tmp11_ = NULL;
		gchar** _tmp12_ = NULL;
		gint _tmp12__length1 = 0;
		const gchar* _tmp13_ = NULL;
		gchar* _tmp14_ = NULL;
		_tmp5_ = aname;
		_tmp7_ = _tmp6_ = g_strsplit (_tmp5_, ":", 0);
		s = _tmp7_;
		s_length1 = _vala_array_length (_tmp6_);
		_s_size_ = s_length1;
		_tmp8_ = s;
		_tmp8__length1 = s_length1;
		if (_tmp8__length1 != 2) {
			s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
			_g_free0 (qname);
			_g_free0 (prefix);
			return;
		}
		_tmp9_ = s;
		_tmp9__length1 = s_length1;
		_tmp10_ = _tmp9_[0];
		_tmp11_ = g_strdup (_tmp10_);
		_g_free0 (prefix);
		prefix = _tmp11_;
		_tmp12_ = s;
		_tmp12__length1 = s_length1;
		_tmp13_ = _tmp12_[1];
		_tmp14_ = g_strdup (_tmp13_);
		_g_free0 (qname);
		qname = _tmp14_;
		s = (_vala_array_free (s, s_length1, (GDestroyNotify) g_free), NULL);
	}
	_tmp15_ = ((GXmlGNode*) self)->_node;
	_tmp16_ = _tmp15_->doc;
	_tmp17_ = ((GXmlGNode*) self)->_node;
	_tmp18_ = ns;
	_tmp19_ = xmlSearchNsByHref (_tmp16_, _tmp17_, _tmp18_);
	ins = _tmp19_;
	_tmp20_ = ins;
	if (_tmp20_ != NULL) {
		xmlNode* _tmp21_ = NULL;
		xmlNs* _tmp22_ = NULL;
		const gchar* _tmp23_ = NULL;
		const gchar* _tmp24_ = NULL;
		_tmp21_ = ((GXmlGNode*) self)->_node;
		_tmp22_ = ins;
		_tmp23_ = qname;
		_tmp24_ = value;
		xmlSetNsProp (_tmp21_, _tmp22_, (xmlChar*) _tmp23_, (xmlChar*) _tmp24_);
		_g_free0 (qname);
		_g_free0 (prefix);
		return;
	}
	_tmp25_ = ((GXmlGNode*) self)->_node;
	_tmp26_ = ns;
	_tmp27_ = prefix;
	_tmp28_ = xmlNewNs (_tmp25_, (xmlChar*) _tmp26_, (xmlChar*) _tmp27_);
	nns = _tmp28_;
	_tmp29_ = nns;
	if (_tmp29_ != NULL) {
		xmlNode* _tmp30_ = NULL;
		xmlNs* _tmp31_ = NULL;
		const gchar* _tmp32_ = NULL;
		const gchar* _tmp33_ = NULL;
		_tmp30_ = ((GXmlGNode*) self)->_node;
		_tmp31_ = nns;
		_tmp32_ = qname;
		_tmp33_ = value;
		xmlSetNsProp (_tmp30_, _tmp31_, (xmlChar*) _tmp32_, (xmlChar*) _tmp33_);
	}
	_g_free0 (qname);
	_g_free0 (prefix);
}


static GXmlNode* gxml_gelement_real_get_ns_attr (GXmlElement* base, const gchar* name, const gchar* uri) {
	GXmlGElement * self;
	GXmlNode* result = NULL;
	xmlNode* _tmp0_ = NULL;
	xmlAttr* a = NULL;
	xmlNode* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	xmlAttr* _tmp4_ = NULL;
	xmlAttr* _tmp5_ = NULL;
	GXmlGDocument* _tmp6_ = NULL;
	xmlAttr* _tmp7_ = NULL;
	GXmlGAttribute* _tmp8_ = NULL;
	self = (GXmlGElement*) base;
	g_return_val_if_fail (name != NULL, NULL);
	g_return_val_if_fail (uri != NULL, NULL);
	_tmp0_ = ((GXmlGNode*) self)->_node;
	if (_tmp0_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp1_ = ((GXmlGNode*) self)->_node;
	_tmp2_ = name;
	_tmp3_ = uri;
	_tmp4_ = xmlHasNsProp (_tmp1_, (xmlChar*) _tmp2_, (xmlChar*) _tmp3_);
	a = _tmp4_;
	_tmp5_ = a;
	if (_tmp5_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp6_ = ((GXmlGNode*) self)->_doc;
	_tmp7_ = a;
	_tmp8_ = gxml_gattribute_new (_tmp6_, _tmp7_);
	result = (GXmlNode*) _tmp8_;
	return result;
}


static void gxml_gelement_real_normalize (GXmlElement* base) {
	GXmlGElement * self;
	self = (GXmlGElement*) base;
}


static void gxml_gelement_real_remove_attr (GXmlElement* base, const gchar* name) {
	GXmlGElement * self;
	xmlNode* _tmp0_ = NULL;
	xmlAttr* a = NULL;
	xmlNode* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	xmlAttr* _tmp3_ = NULL;
	xmlAttr* _tmp4_ = NULL;
	xmlAttr* _tmp5_ = NULL;
	self = (GXmlGElement*) base;
	g_return_if_fail (name != NULL);
	_tmp0_ = ((GXmlGNode*) self)->_node;
	if (_tmp0_ == NULL) {
		return;
	}
	_tmp1_ = ((GXmlGNode*) self)->_node;
	_tmp2_ = name;
	_tmp3_ = xmlHasProp (_tmp1_, (xmlChar*) _tmp2_);
	a = _tmp3_;
	_tmp4_ = a;
	if (_tmp4_ == NULL) {
		return;
	}
	_tmp5_ = a;
	xmlRemoveProp (_tmp5_);
}


static void gxml_gelement_real_remove_ns_attr (GXmlElement* base, const gchar* name, const gchar* uri) {
	GXmlGElement * self;
	xmlNode* _tmp0_ = NULL;
	xmlAttr* a = NULL;
	xmlNode* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	xmlAttr* _tmp4_ = NULL;
	xmlAttr* _tmp5_ = NULL;
	xmlAttr* _tmp6_ = NULL;
	self = (GXmlGElement*) base;
	g_return_if_fail (name != NULL);
	g_return_if_fail (uri != NULL);
	_tmp0_ = ((GXmlGNode*) self)->_node;
	if (_tmp0_ == NULL) {
		return;
	}
	_tmp1_ = ((GXmlGNode*) self)->_node;
	_tmp2_ = name;
	_tmp3_ = uri;
	_tmp4_ = xmlHasNsProp (_tmp1_, (xmlChar*) _tmp2_, (xmlChar*) _tmp3_);
	a = _tmp4_;
	_tmp5_ = a;
	if (_tmp5_ == NULL) {
		return;
	}
	_tmp6_ = a;
	xmlRemoveProp (_tmp6_);
}


static gchar* gxml_gelement_real_to_string (GXmlGNode* base) {
	GXmlGElement * self;
	gchar* result = NULL;
	xmlBuffer* buf = NULL;
	xmlBuffer* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlDoc* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = xmlBufferCreate ();
	buf = _tmp0_;
	_tmp1_ = ((GXmlGNode*) self)->_node;
	_tmp2_ = _tmp1_->doc;
	_tmp3_ = ((GXmlGNode*) self)->_node;
	xmlNodeDump (buf, _tmp2_, _tmp3_, 1, 0);
	_tmp4_ = xmlBufferContent (buf);
	_tmp5_ = g_strdup (_tmp4_);
	result = _tmp5_;
	_xmlBufferFree0 (buf);
	return result;
}


static gchar* gxml_gelement_real_get_attribute (GXmlDomElement* base, const gchar* name) {
	GXmlGElement * self;
	gchar* result = NULL;
	GXmlNode* p = NULL;
	GeeMap* _tmp0_ = NULL;
	GeeMap* _tmp1_ = NULL;
	GeeMap* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gpointer _tmp4_ = NULL;
	GXmlNode* _tmp5_ = NULL;
	GXmlNode* _tmp6_ = NULL;
	GXmlNode* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	self = (GXmlGElement*) base;
	g_return_val_if_fail (name != NULL, NULL);
	_tmp0_ = gxml_gnode_get_attrs ((GXmlGNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = name;
	_tmp4_ = gee_map_get (_tmp2_, _tmp3_);
	_tmp5_ = (GXmlNode*) _tmp4_;
	_g_object_unref0 (_tmp2_);
	p = _tmp5_;
	_tmp6_ = p;
	if (_tmp6_ == NULL) {
		result = NULL;
		_g_object_unref0 (p);
		return result;
	}
	_tmp7_ = p;
	_tmp8_ = gxml_node_get_value (_tmp7_);
	_tmp9_ = _tmp8_;
	result = _tmp9_;
	_g_object_unref0 (p);
	return result;
}


static gchar* gxml_gelement_real_get_attribute_ns (GXmlDomElement* base, const gchar* namespace, const gchar* local_name) {
	GXmlGElement * self;
	gchar* result = NULL;
	GXmlNode* p = NULL;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	GXmlNode* _tmp2_ = NULL;
	GXmlNode* _tmp3_ = NULL;
	GXmlNode* _tmp4_ = NULL;
	gchar* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	self = (GXmlGElement*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = local_name;
	_tmp1_ = namespace;
	_tmp2_ = gxml_element_get_ns_attr ((GXmlElement*) self, _tmp0_, _tmp1_);
	p = _tmp2_;
	_tmp3_ = p;
	if (_tmp3_ == NULL) {
		result = NULL;
		_g_object_unref0 (p);
		return result;
	}
	_tmp4_ = p;
	_tmp5_ = gxml_node_get_value (_tmp4_);
	_tmp6_ = _tmp5_;
	result = _tmp6_;
	_g_object_unref0 (p);
	return result;
}


static void gxml_gelement_real_set_attribute (GXmlDomElement* base, const gchar* name, const gchar* value, GError** error) {
	GXmlGElement * self;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	self = (GXmlGElement*) base;
	g_return_if_fail (name != NULL);
	g_return_if_fail (value != NULL);
	_tmp0_ = name;
	_tmp1_ = value;
	gxml_element_set_attr ((GXmlElement*) self, _tmp0_, _tmp1_);
}


static void gxml_gelement_real_set_attribute_ns (GXmlDomElement* base, const gchar* namespace, const gchar* name, const gchar* value, GError** error) {
	GXmlGElement * self;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	self = (GXmlGElement*) base;
	g_return_if_fail (name != NULL);
	g_return_if_fail (value != NULL);
	_tmp0_ = namespace;
	_tmp1_ = name;
	_tmp2_ = value;
	gxml_element_set_ns_attr ((GXmlElement*) self, _tmp0_, _tmp1_, _tmp2_);
}


static void gxml_gelement_real_remove_attribute (GXmlDomElement* base, const gchar* name) {
	GXmlGElement * self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGElement*) base;
	g_return_if_fail (name != NULL);
	_tmp0_ = name;
	gxml_element_remove_attr ((GXmlElement*) self, _tmp0_);
}


static void gxml_gelement_real_remove_attribute_ns (GXmlDomElement* base, const gchar* namespace, const gchar* local_name) {
	GXmlGElement * self;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	self = (GXmlGElement*) base;
	g_return_if_fail (local_name != NULL);
	_tmp0_ = local_name;
	_tmp1_ = namespace;
	gxml_element_remove_ns_attr ((GXmlElement*) self, _tmp0_, _tmp1_);
}


static gboolean gxml_gelement_real_has_attribute (GXmlDomElement* base, const gchar* name) {
	GXmlGElement * self;
	gboolean result = FALSE;
	GeeMap* _tmp0_ = NULL;
	GeeMap* _tmp1_ = NULL;
	GeeMap* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	self = (GXmlGElement*) base;
	g_return_val_if_fail (name != NULL, FALSE);
	_tmp0_ = gxml_gnode_get_attrs ((GXmlGNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = name;
	_tmp4_ = gee_map_has_key (_tmp2_, _tmp3_);
	_tmp5_ = _tmp4_;
	_g_object_unref0 (_tmp2_);
	result = _tmp5_;
	return result;
}


static gboolean gxml_gelement_real_has_attribute_ns (GXmlDomElement* base, const gchar* namespace, const gchar* local_name) {
	GXmlGElement * self;
	gboolean result = FALSE;
	xmlNode* _tmp0_ = NULL;
	xmlAttr* attr = NULL;
	xmlNode* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	xmlAttr* _tmp4_ = NULL;
	xmlAttr* _tmp5_ = NULL;
	self = (GXmlGElement*) base;
	g_return_val_if_fail (local_name != NULL, FALSE);
	_tmp0_ = ((GXmlGNode*) self)->_node;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = ((GXmlGNode*) self)->_node;
	_tmp2_ = local_name;
	_tmp3_ = namespace;
	_tmp4_ = xmlHasNsProp (_tmp1_, (xmlChar*) _tmp2_, (xmlChar*) _tmp3_);
	attr = _tmp4_;
	_tmp5_ = attr;
	if (_tmp5_ == NULL) {
		result = FALSE;
		return result;
	}
	result = TRUE;
	return result;
}


static GXmlDomHTMLCollection* gxml_gelement_real_get_elements_by_tag_name (GXmlDomElement* base, const gchar* local_name) {
	GXmlGElement * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_ = NULL;
	self = (GXmlGElement*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	{
		GXmlDomHTMLCollection* _n_list = NULL;
		GXmlDomHTMLCollection* _tmp1_ = NULL;
		GXmlDomHTMLCollection* _tmp2_ = NULL;
		gint _n_size = 0;
		GXmlDomHTMLCollection* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
		gint _n_index = 0;
		_tmp1_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
		_tmp2_ = _tmp1_;
		_n_list = _tmp2_;
		_tmp3_ = _n_list;
		_tmp4_ = gee_collection_get_size ((GeeCollection*) _tmp3_);
		_tmp5_ = _tmp4_;
		_n_size = _tmp5_;
		_n_index = -1;
		while (TRUE) {
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			gint _tmp8_ = 0;
			GXmlDomElement* n = NULL;
			GXmlDomHTMLCollection* _tmp9_ = NULL;
			gint _tmp10_ = 0;
			gpointer _tmp11_ = NULL;
			GXmlDomElement* _tmp12_ = NULL;
			gchar* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
			const gchar* _tmp16_ = NULL;
			gboolean _tmp17_ = FALSE;
			GXmlGDomHTMLCollection* _tmp20_ = NULL;
			GXmlDomElement* _tmp21_ = NULL;
			const gchar* _tmp22_ = NULL;
			GXmlDomHTMLCollection* _tmp23_ = NULL;
			GXmlDomHTMLCollection* _tmp24_ = NULL;
			_tmp6_ = _n_index;
			_n_index = _tmp6_ + 1;
			_tmp7_ = _n_index;
			_tmp8_ = _n_size;
			if (!(_tmp7_ < _tmp8_)) {
				break;
			}
			_tmp9_ = _n_list;
			_tmp10_ = _n_index;
			_tmp11_ = gee_list_get ((GeeList*) _tmp9_, _tmp10_);
			n = (GXmlDomElement*) _tmp11_;
			_tmp12_ = n;
			_tmp13_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp12_);
			_tmp14_ = _tmp13_;
			_tmp15_ = _tmp14_;
			_tmp16_ = local_name;
			_tmp17_ = g_strcmp0 (_tmp15_, _tmp16_) == 0;
			_g_free0 (_tmp15_);
			if (_tmp17_) {
				GXmlGDomHTMLCollection* _tmp18_ = NULL;
				GXmlDomElement* _tmp19_ = NULL;
				_tmp18_ = l;
				_tmp19_ = n;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp18_, _tmp19_);
			}
			_tmp20_ = l;
			_tmp21_ = n;
			_tmp22_ = local_name;
			_tmp23_ = gxml_dom_element_get_elements_by_tag_name (_tmp21_, _tmp22_);
			_tmp24_ = _tmp23_;
			gee_array_list_add_all ((GeeArrayList*) _tmp20_, (GeeCollection*) _tmp24_);
			_g_object_unref0 (_tmp24_);
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	return result;
}


static GXmlDomHTMLCollection* gxml_gelement_real_get_elements_by_tag_name_ns (GXmlDomElement* base, const gchar* namespace, const gchar* local_name) {
	GXmlGElement * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_ = NULL;
	self = (GXmlGElement*) base;
	g_return_val_if_fail (local_name != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	{
		GXmlDomHTMLCollection* _n_list = NULL;
		GXmlDomHTMLCollection* _tmp1_ = NULL;
		GXmlDomHTMLCollection* _tmp2_ = NULL;
		gint _n_size = 0;
		GXmlDomHTMLCollection* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
		gint _n_index = 0;
		_tmp1_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
		_tmp2_ = _tmp1_;
		_n_list = _tmp2_;
		_tmp3_ = _n_list;
		_tmp4_ = gee_collection_get_size ((GeeCollection*) _tmp3_);
		_tmp5_ = _tmp4_;
		_n_size = _tmp5_;
		_n_index = -1;
		while (TRUE) {
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			gint _tmp8_ = 0;
			GXmlDomElement* n = NULL;
			GXmlDomHTMLCollection* _tmp9_ = NULL;
			gint _tmp10_ = 0;
			gpointer _tmp11_ = NULL;
			gboolean _tmp12_ = FALSE;
			GXmlDomElement* _tmp13_ = NULL;
			gchar* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			const gchar* _tmp17_ = NULL;
			gboolean _tmp18_ = FALSE;
			GXmlGDomHTMLCollection* _tmp26_ = NULL;
			GXmlDomElement* _tmp27_ = NULL;
			const gchar* _tmp28_ = NULL;
			const gchar* _tmp29_ = NULL;
			GXmlDomHTMLCollection* _tmp30_ = NULL;
			GXmlDomHTMLCollection* _tmp31_ = NULL;
			_tmp6_ = _n_index;
			_n_index = _tmp6_ + 1;
			_tmp7_ = _n_index;
			_tmp8_ = _n_size;
			if (!(_tmp7_ < _tmp8_)) {
				break;
			}
			_tmp9_ = _n_list;
			_tmp10_ = _n_index;
			_tmp11_ = gee_list_get ((GeeList*) _tmp9_, _tmp10_);
			n = (GXmlDomElement*) _tmp11_;
			_tmp13_ = n;
			_tmp14_ = gxml_dom_node_get_node_name ((GXmlDomNode*) _tmp13_);
			_tmp15_ = _tmp14_;
			_tmp16_ = _tmp15_;
			_tmp17_ = local_name;
			_tmp18_ = g_strcmp0 (_tmp16_, _tmp17_) == 0;
			_g_free0 (_tmp16_);
			if (_tmp18_) {
				GXmlDomElement* _tmp19_ = NULL;
				gchar* _tmp20_ = NULL;
				gchar* _tmp21_ = NULL;
				gchar* _tmp22_ = NULL;
				const gchar* _tmp23_ = NULL;
				_tmp19_ = n;
				_tmp20_ = gxml_dom_element_get_namespace_uri (_tmp19_);
				_tmp21_ = _tmp20_;
				_tmp22_ = _tmp21_;
				_tmp23_ = namespace;
				_tmp12_ = g_strcmp0 (_tmp22_, _tmp23_) == 0;
				_g_free0 (_tmp22_);
			} else {
				_tmp12_ = FALSE;
			}
			if (_tmp12_) {
				GXmlGDomHTMLCollection* _tmp24_ = NULL;
				GXmlDomElement* _tmp25_ = NULL;
				_tmp24_ = l;
				_tmp25_ = n;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp24_, _tmp25_);
			}
			_tmp26_ = l;
			_tmp27_ = n;
			_tmp28_ = namespace;
			_tmp29_ = local_name;
			_tmp30_ = gxml_dom_element_get_elements_by_tag_name_ns (_tmp27_, _tmp28_, _tmp29_);
			_tmp31_ = _tmp30_;
			gee_array_list_add_all ((GeeArrayList*) _tmp26_, (GeeCollection*) _tmp31_);
			_g_object_unref0 (_tmp31_);
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	return result;
}


static void _vala_array_add6 (gchar*** array, int* length, int* size, gchar* value) {
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}


static void _vala_array_add7 (gchar*** array, int* length, int* size, gchar* value) {
	if ((*length) == (*size)) {
		*size = (*size) ? (2 * (*size)) : 4;
		*array = g_renew (gchar*, *array, (*size) + 1);
	}
	(*array)[(*length)++] = value;
	(*array)[*length] = NULL;
}


static GXmlDomHTMLCollection* gxml_gelement_real_get_elements_by_class_name (GXmlDomElement* base, const gchar* class_names) {
	GXmlGElement * self;
	GXmlDomHTMLCollection* result = NULL;
	GXmlGDomHTMLCollection* l = NULL;
	GXmlGDomHTMLCollection* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	gchar** cs = NULL;
	gchar** _tmp2_ = NULL;
	gint cs_length1 = 0;
	gint _cs_size_ = 0;
	const gchar* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	self = (GXmlGElement*) base;
	g_return_val_if_fail (class_names != NULL, NULL);
	_tmp0_ = gxml_gdom_html_collection_new ();
	l = _tmp0_;
	_tmp1_ = class_names;
	if (g_strcmp0 (_tmp1_, "") == 0) {
		result = (GXmlDomHTMLCollection*) l;
		return result;
	}
	_tmp2_ = g_new0 (gchar*, 0 + 1);
	cs = _tmp2_;
	cs_length1 = 0;
	_cs_size_ = cs_length1;
	_tmp3_ = class_names;
	_tmp4_ = string_contains (_tmp3_, " ");
	if (_tmp4_) {
		const gchar* _tmp5_ = NULL;
		gchar** _tmp6_ = NULL;
		gchar** _tmp7_ = NULL;
		_tmp5_ = class_names;
		_tmp7_ = _tmp6_ = g_strsplit (_tmp5_, " ", 0);
		cs = (_vala_array_free (cs, cs_length1, (GDestroyNotify) g_free), NULL);
		cs = _tmp7_;
		cs_length1 = _vala_array_length (_tmp6_);
		_cs_size_ = cs_length1;
	} else {
		gchar** _tmp8_ = NULL;
		gint _tmp8__length1 = 0;
		const gchar* _tmp9_ = NULL;
		gchar* _tmp10_ = NULL;
		_tmp8_ = cs;
		_tmp8__length1 = cs_length1;
		_tmp9_ = class_names;
		_tmp10_ = g_strdup (_tmp9_);
		_vala_array_add6 (&cs, &cs_length1, &_cs_size_, _tmp10_);
	}
	{
		GXmlDomHTMLCollection* _n_list = NULL;
		GXmlDomHTMLCollection* _tmp11_ = NULL;
		GXmlDomHTMLCollection* _tmp12_ = NULL;
		gint _n_size = 0;
		GXmlDomHTMLCollection* _tmp13_ = NULL;
		gint _tmp14_ = 0;
		gint _tmp15_ = 0;
		gint _n_index = 0;
		_tmp11_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
		_tmp12_ = _tmp11_;
		_n_list = _tmp12_;
		_tmp13_ = _n_list;
		_tmp14_ = gee_collection_get_size ((GeeCollection*) _tmp13_);
		_tmp15_ = _tmp14_;
		_n_size = _tmp15_;
		_n_index = -1;
		while (TRUE) {
			gint _tmp16_ = 0;
			gint _tmp17_ = 0;
			gint _tmp18_ = 0;
			GXmlDomElement* n = NULL;
			GXmlDomHTMLCollection* _tmp19_ = NULL;
			gint _tmp20_ = 0;
			gpointer _tmp21_ = NULL;
			gchar* cls = NULL;
			GXmlDomElement* _tmp22_ = NULL;
			gchar* _tmp23_ = NULL;
			const gchar* _tmp24_ = NULL;
			GXmlGDomHTMLCollection* _tmp50_ = NULL;
			GXmlDomElement* _tmp51_ = NULL;
			const gchar* _tmp52_ = NULL;
			GXmlDomHTMLCollection* _tmp53_ = NULL;
			GXmlDomHTMLCollection* _tmp54_ = NULL;
			_tmp16_ = _n_index;
			_n_index = _tmp16_ + 1;
			_tmp17_ = _n_index;
			_tmp18_ = _n_size;
			if (!(_tmp17_ < _tmp18_)) {
				break;
			}
			_tmp19_ = _n_list;
			_tmp20_ = _n_index;
			_tmp21_ = gee_list_get ((GeeList*) _tmp19_, _tmp20_);
			n = (GXmlDomElement*) _tmp21_;
			_tmp22_ = n;
			_tmp23_ = gxml_dom_element_get_attribute (_tmp22_, "class");
			cls = _tmp23_;
			_tmp24_ = cls;
			if (_tmp24_ != NULL) {
				gchar** ncls = NULL;
				gchar** _tmp25_ = NULL;
				gint ncls_length1 = 0;
				gint _ncls_size_ = 0;
				const gchar* _tmp26_ = NULL;
				gboolean _tmp27_ = FALSE;
				gint found = 0;
				gchar** _tmp34_ = NULL;
				gint _tmp34__length1 = 0;
				gint _tmp41_ = 0;
				gchar** _tmp42_ = NULL;
				gint _tmp42__length1 = 0;
				_tmp25_ = g_new0 (gchar*, 0 + 1);
				ncls = _tmp25_;
				ncls_length1 = 0;
				_ncls_size_ = ncls_length1;
				_tmp26_ = cls;
				_tmp27_ = string_contains (_tmp26_, " ");
				if (_tmp27_) {
					const gchar* _tmp28_ = NULL;
					gchar** _tmp29_ = NULL;
					gchar** _tmp30_ = NULL;
					_tmp28_ = cls;
					_tmp30_ = _tmp29_ = g_strsplit (_tmp28_, " ", 0);
					ncls = (_vala_array_free (ncls, ncls_length1, (GDestroyNotify) g_free), NULL);
					ncls = _tmp30_;
					ncls_length1 = _vala_array_length (_tmp29_);
					_ncls_size_ = ncls_length1;
				} else {
					gchar** _tmp31_ = NULL;
					gint _tmp31__length1 = 0;
					const gchar* _tmp32_ = NULL;
					gchar* _tmp33_ = NULL;
					_tmp31_ = ncls;
					_tmp31__length1 = ncls_length1;
					_tmp32_ = cls;
					_tmp33_ = g_strdup (_tmp32_);
					_vala_array_add7 (&ncls, &ncls_length1, &_ncls_size_, _tmp33_);
				}
				found = 0;
				_tmp34_ = cs;
				_tmp34__length1 = cs_length1;
				{
					gchar** cl_collection = NULL;
					gint cl_collection_length1 = 0;
					gint _cl_collection_size_ = 0;
					gint cl_it = 0;
					cl_collection = _tmp34_;
					cl_collection_length1 = _tmp34__length1;
					for (cl_it = 0; cl_it < _tmp34__length1; cl_it = cl_it + 1) {
						gchar* _tmp35_ = NULL;
						gchar* cl = NULL;
						_tmp35_ = g_strdup (cl_collection[cl_it]);
						cl = _tmp35_;
						{
							gchar** _tmp36_ = NULL;
							gint _tmp36__length1 = 0;
							_tmp36_ = ncls;
							_tmp36__length1 = ncls_length1;
							{
								gchar** ncl_collection = NULL;
								gint ncl_collection_length1 = 0;
								gint _ncl_collection_size_ = 0;
								gint ncl_it = 0;
								ncl_collection = _tmp36_;
								ncl_collection_length1 = _tmp36__length1;
								for (ncl_it = 0; ncl_it < _tmp36__length1; ncl_it = ncl_it + 1) {
									gchar* _tmp37_ = NULL;
									gchar* ncl = NULL;
									_tmp37_ = g_strdup (ncl_collection[ncl_it]);
									ncl = _tmp37_;
									{
										const gchar* _tmp38_ = NULL;
										const gchar* _tmp39_ = NULL;
										_tmp38_ = cl;
										_tmp39_ = ncl;
										if (g_strcmp0 (_tmp38_, _tmp39_) == 0) {
											gint _tmp40_ = 0;
											_tmp40_ = found;
											found = _tmp40_ + 1;
										}
										_g_free0 (ncl);
									}
								}
							}
							_g_free0 (cl);
						}
					}
				}
				_tmp41_ = found;
				_tmp42_ = cs;
				_tmp42__length1 = cs_length1;
				if (_tmp41_ == _tmp42__length1) {
					GXmlGDomHTMLCollection* _tmp43_ = NULL;
					gint _tmp44_ = 0;
					gint _tmp45_ = 0;
					_tmp43_ = l;
					_tmp44_ = gee_abstract_collection_get_size ((GeeAbstractCollection*) _tmp43_);
					_tmp45_ = _tmp44_;
					if (_tmp45_ == 0) {
						GXmlGDomHTMLCollection* _tmp46_ = NULL;
						GXmlDomElement* _tmp47_ = NULL;
						_tmp46_ = l;
						_tmp47_ = n;
						gee_abstract_collection_add ((GeeAbstractCollection*) _tmp46_, _tmp47_);
					} else {
						GXmlGDomHTMLCollection* _tmp48_ = NULL;
						GXmlDomElement* _tmp49_ = NULL;
						_tmp48_ = l;
						_tmp49_ = n;
						gee_abstract_list_insert ((GeeAbstractList*) _tmp48_, 0, _tmp49_);
					}
				}
				ncls = (_vala_array_free (ncls, ncls_length1, (GDestroyNotify) g_free), NULL);
			}
			_tmp50_ = l;
			_tmp51_ = n;
			_tmp52_ = class_names;
			_tmp53_ = gxml_dom_element_get_elements_by_class_name (_tmp51_, _tmp52_);
			_tmp54_ = _tmp53_;
			gee_array_list_add_all ((GeeArrayList*) _tmp50_, (GeeCollection*) _tmp54_);
			_g_object_unref0 (_tmp54_);
			_g_free0 (cls);
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	cs = (_vala_array_free (cs, cs_length1, (GDestroyNotify) g_free), NULL);
	return result;
}


static GXmlDomElement* gxml_gelement_real_query_selector (GXmlDomParentNode* base, const gchar* selectors, GError** error) {
	GXmlGElement * self;
	GXmlDomElement* result = NULL;
	const gchar* _tmp0_ = NULL;
	GError* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGElement*) base;
	g_return_val_if_fail (selectors != NULL, NULL);
	_tmp0_ = _ ("DomElement query_selector is not implemented");
	_tmp1_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_SYNTAX_ERROR, _tmp0_);
	_inner_error_ = _tmp1_;
	g_propagate_error (error, _inner_error_);
	return NULL;
	return result;
}


static GXmlDomNodeList* gxml_gelement_real_query_selector_all (GXmlDomParentNode* base, const gchar* selectors, GError** error) {
	GXmlGElement * self;
	GXmlDomNodeList* result = NULL;
	const gchar* _tmp0_ = NULL;
	GError* _tmp1_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGElement*) base;
	g_return_val_if_fail (selectors != NULL, NULL);
	_tmp0_ = _ ("DomElement query_selector_all is not implemented");
	_tmp1_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_SYNTAX_ERROR, _tmp0_);
	_inner_error_ = _tmp1_;
	g_propagate_error (error, _inner_error_);
	return NULL;
	return result;
}


/**
   * {@inheritDoc}
   */
static Block1Data* block1_data_ref (Block1Data* _data1_) {
	g_atomic_int_inc (&_data1_->_ref_count_);
	return _data1_;
}


static void block1_data_unref (void * _userdata_) {
	Block1Data* _data1_;
	_data1_ = (Block1Data*) _userdata_;
	if (g_atomic_int_dec_and_test (&_data1_->_ref_count_)) {
		GXmlGElement* self;
		self = _data1_->self;
		_xmlXPathFreeContext0 (_data1_->context);
		_g_object_unref0 (self);
		g_slice_free (Block1Data, _data1_);
	}
}


static gboolean ___lambda4_ (Block1Data* _data1_, GXmlNamespace* ns) {
	GXmlGElement* self;
	gboolean result = FALSE;
	gint res = 0;
	xmlXPathContext* _tmp0_ = NULL;
	GXmlNamespace* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	GXmlNamespace* _tmp5_ = NULL;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	gint _tmp9_ = 0;
	gint _tmp10_ = 0;
	gint _tmp11_ = 0;
	self = _data1_->self;
	g_return_val_if_fail (ns != NULL, FALSE);
	_tmp0_ = _data1_->context;
	_tmp1_ = ns;
	_tmp2_ = gxml_namespace_get_prefix (_tmp1_);
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_;
	_tmp5_ = ns;
	_tmp6_ = gxml_namespace_get_uri (_tmp5_);
	_tmp7_ = _tmp6_;
	_tmp8_ = _tmp7_;
	_tmp9_ = xmlXPathRegisterNs (_tmp0_, (xmlChar*) _tmp4_, (xmlChar*) _tmp8_);
	_tmp10_ = _tmp9_;
	_g_free0 (_tmp8_);
	_g_free0 (_tmp4_);
	res = _tmp10_;
	_tmp11_ = res;
	if (_tmp11_ != 0) {
		const gchar* _tmp12_ = NULL;
		gint _tmp13_ = 0;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_ = NULL;
		_tmp12_ = _ ("invalid namespace. Code: ");
		_tmp13_ = res;
		_tmp14_ = g_strdup_printf ("%i", _tmp13_);
		_tmp15_ = _tmp14_;
		_tmp16_ = g_strconcat (_tmp12_, _tmp15_, NULL);
		_tmp17_ = _tmp16_;
		g_warning ("GXmlElement.vala:342: %s", _tmp17_);
		_g_free0 (_tmp17_);
		_g_free0 (_tmp15_);
	}
	result = TRUE;
	_g_object_unref0 (ns);
	return result;
}


static gboolean ____lambda4__gee_forall_func (gpointer g, gpointer self) {
	gboolean result;
	result = ___lambda4_ (self, (GXmlNamespace*) g);
	return result;
}


static GXmlXPathObject* gxml_gelement_real_evaluate (GXmlXPathContext* base, const gchar* expression, GeeList* resolver, GError** error) {
	GXmlGElement * self;
	GXmlXPathObject* result = NULL;
	Block1Data* _data1_;
	GXmlXPathObject* nullobj = NULL;
	gchar* data = NULL;
	gchar* _tmp0_ = NULL;
	xmlDoc* ndoc = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	xmlDoc* _tmp5_ = NULL;
	GXmlGDocument* gdoc = NULL;
	xmlDoc* _tmp6_ = NULL;
	GXmlGDocument* _tmp7_ = NULL;
	xmlDoc* _tmp8_ = NULL;
	xmlXPathContext* _tmp9_ = NULL;
	GeeList* _tmp10_ = NULL;
	GXmlGDocument* _tmp12_ = NULL;
	xmlXPathContext* _tmp13_ = NULL;
	const gchar* _tmp14_ = NULL;
	xmlXPathObject* _tmp15_ = NULL;
	GXmlGXPathObject* _tmp16_ = NULL;
	self = (GXmlGElement*) base;
	g_return_val_if_fail (expression != NULL, NULL);
	_data1_ = g_slice_new0 (Block1Data);
	_data1_->_ref_count_ = 1;
	_data1_->self = g_object_ref (self);
	nullobj = NULL;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_NODE)) {
		result = nullobj;
		block1_data_unref (_data1_);
		_data1_ = NULL;
		return result;
	}
	_tmp0_ = gxml_node_to_string (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_NODE) ? ((GXmlNode*) self) : NULL);
	data = _tmp0_;
	_tmp1_ = data;
	_tmp2_ = data;
	_tmp3_ = strlen (_tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = xmlReadMemory (_tmp1_, _tmp4_, NULL, NULL, 0);
	ndoc = _tmp5_;
	_tmp6_ = ndoc;
	_tmp7_ = gxml_gdocument_new_from_doc (_tmp6_);
	gdoc = _tmp7_;
	_tmp8_ = ndoc;
	_tmp9_ = xmlXPathNewContext (_tmp8_);
	_data1_->context = _tmp9_;
	_tmp10_ = resolver;
	if (_tmp10_ != NULL) {
		GeeList* _tmp11_ = NULL;
		_tmp11_ = resolver;
		gee_traversable_foreach ((GeeTraversable*) _tmp11_, ____lambda4__gee_forall_func, _data1_);
	}
	_tmp12_ = gdoc;
	_tmp13_ = _data1_->context;
	_tmp14_ = expression;
	_tmp15_ = xmlXPathEval ((xmlChar*) _tmp14_, _tmp13_);
	_tmp16_ = gxml_gx_path_object_new (_tmp12_, _tmp15_);
	result = (GXmlXPathObject*) _tmp16_;
	_g_object_unref0 (gdoc);
	_g_free0 (data);
	_g_object_unref0 (nullobj);
	block1_data_unref (_data1_);
	_data1_ = NULL;
	return result;
}


static gchar* gxml_gelement_real_get_value (GXmlGNode* base) {
	gchar* result;
	GXmlGElement* self;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = gxml_element_get_content ((GXmlElement*) self);
	_tmp1_ = _tmp0_;
	result = _tmp1_;
	return result;
}


static void gxml_gelement_real_set_value (GXmlGNode* base, const gchar* value) {
	GXmlGElement* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = value;
	gxml_element_set_content ((GXmlElement*) self, _tmp0_);
	g_object_notify ((GObject *) self, "value");
}


static gchar* gxml_gelement_real_get_content (GXmlElement* base) {
	gchar* result;
	GXmlGElement* self;
	xmlNode* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = ((GXmlGNode*) self)->_node;
	_tmp1_ = (gchar*) xmlNodeGetContent (_tmp0_);
	_tmp2_ = _tmp1_;
	_tmp3_ = g_strdup (_tmp2_);
	_tmp4_ = _tmp3_;
	_g_free0 (_tmp2_);
	result = _tmp4_;
	return result;
}


static void gxml_gelement_real_set_content (GXmlElement* base, const gchar* value) {
	GXmlGElement* self;
	xmlNode* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = ((GXmlGNode*) self)->_node;
	_tmp1_ = value;
	xmlNodeSetContent (_tmp0_, (xmlChar*) _tmp1_);
	g_object_notify ((GObject *) self, "content");
}


static gchar* gxml_gelement_real_get_tag_name (GXmlDomElement* base) {
	gchar* result;
	GXmlGElement* self;
	xmlNode* _tmp0_ = NULL;
	xmlNs* ns = NULL;
	xmlNode* _tmp2_ = NULL;
	xmlNs* _tmp3_ = NULL;
	xmlNs* dns = NULL;
	xmlNs* _tmp4_ = NULL;
	xmlNs* _tmp11_ = NULL;
	xmlNode* _tmp35_ = NULL;
	const gchar* _tmp36_ = NULL;
	gchar* _tmp37_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = ((GXmlGNode*) self)->_node;
	if (_tmp0_ == NULL) {
		gchar* _tmp1_ = NULL;
		_tmp1_ = g_strdup ("");
		result = _tmp1_;
		return result;
	}
	_tmp2_ = ((GXmlGNode*) self)->_node;
	_tmp3_ = _tmp2_->nsDef;
	ns = _tmp3_;
	_tmp4_ = ns;
	dns = _tmp4_;
	while (TRUE) {
		xmlNs* _tmp5_ = NULL;
		xmlNs* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		xmlNs* _tmp9_ = NULL;
		xmlNs* _tmp10_ = NULL;
		_tmp5_ = ns;
		if (!(_tmp5_ != NULL)) {
			break;
		}
		_tmp6_ = ns;
		_tmp7_ = _tmp6_->prefix;
		if (_tmp7_ == NULL) {
			xmlNs* _tmp8_ = NULL;
			_tmp8_ = ns;
			dns = _tmp8_;
		}
		_tmp9_ = ns;
		_tmp10_ = _tmp9_->next;
		ns = _tmp10_;
	}
	_tmp11_ = dns;
	if (_tmp11_ != NULL) {
		xmlNs* _tmp12_ = NULL;
		const gchar* _tmp13_ = NULL;
		xmlNs* _tmp20_ = NULL;
		const gchar* _tmp21_ = NULL;
		gchar* qname = NULL;
		xmlNs* _tmp25_ = NULL;
		const gchar* _tmp26_ = NULL;
		gchar* _tmp27_ = NULL;
		gchar* _tmp28_ = NULL;
		xmlNode* _tmp29_ = NULL;
		const gchar* _tmp30_ = NULL;
		gchar* _tmp31_ = NULL;
		gchar* _tmp32_ = NULL;
		const gchar* _tmp33_ = NULL;
		gchar* _tmp34_ = NULL;
		_tmp12_ = dns;
		_tmp13_ = _tmp12_->href;
		if (g_strcmp0 (_tmp13_, "http://www.w3.org/1999/xhtml") == 0) {
			xmlNode* _tmp14_ = NULL;
			const gchar* _tmp15_ = NULL;
			gchar* _tmp16_ = NULL;
			gchar* _tmp17_ = NULL;
			gchar* _tmp18_ = NULL;
			gchar* _tmp19_ = NULL;
			_tmp14_ = ((GXmlGNode*) self)->_node;
			_tmp15_ = _tmp14_->name;
			_tmp16_ = g_utf8_strup (_tmp15_, (gssize) -1);
			_tmp17_ = _tmp16_;
			_tmp18_ = g_strdup (_tmp17_);
			_tmp19_ = _tmp18_;
			_g_free0 (_tmp17_);
			result = _tmp19_;
			return result;
		}
		_tmp20_ = dns;
		_tmp21_ = _tmp20_->prefix;
		if (_tmp21_ == NULL) {
			xmlNode* _tmp22_ = NULL;
			const gchar* _tmp23_ = NULL;
			gchar* _tmp24_ = NULL;
			_tmp22_ = ((GXmlGNode*) self)->_node;
			_tmp23_ = _tmp22_->name;
			_tmp24_ = g_strdup (_tmp23_);
			result = _tmp24_;
			return result;
		}
		_tmp25_ = dns;
		_tmp26_ = _tmp25_->prefix;
		_tmp27_ = g_strconcat (_tmp26_, ":", NULL);
		_tmp28_ = _tmp27_;
		_tmp29_ = ((GXmlGNode*) self)->_node;
		_tmp30_ = _tmp29_->name;
		_tmp31_ = g_strconcat (_tmp28_, _tmp30_, NULL);
		_tmp32_ = _tmp31_;
		_g_free0 (_tmp28_);
		qname = _tmp32_;
		_tmp33_ = qname;
		_tmp34_ = g_strdup (_tmp33_);
		result = _tmp34_;
		_g_free0 (qname);
		return result;
	}
	_tmp35_ = ((GXmlGNode*) self)->_node;
	_tmp36_ = _tmp35_->name;
	_tmp37_ = g_strdup (_tmp36_);
	result = _tmp37_;
	return result;
}


static gchar* gxml_gelement_real_get_namespace_uri (GXmlDomElement* base) {
	gchar* result;
	GXmlGElement* self;
	xmlNode* _tmp0_ = NULL;
	xmlNs* ns = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNs* _tmp2_ = NULL;
	xmlNs* dns = NULL;
	xmlNs* _tmp3_ = NULL;
	xmlNs* _tmp10_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = ((GXmlGNode*) self)->_node;
	if (_tmp0_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp1_ = ((GXmlGNode*) self)->_node;
	_tmp2_ = _tmp1_->nsDef;
	ns = _tmp2_;
	_tmp3_ = ns;
	dns = _tmp3_;
	while (TRUE) {
		xmlNs* _tmp4_ = NULL;
		xmlNs* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		xmlNs* _tmp8_ = NULL;
		xmlNs* _tmp9_ = NULL;
		_tmp4_ = ns;
		if (!(_tmp4_ != NULL)) {
			break;
		}
		_tmp5_ = ns;
		_tmp6_ = _tmp5_->prefix;
		if (_tmp6_ == NULL) {
			xmlNs* _tmp7_ = NULL;
			_tmp7_ = ns;
			dns = _tmp7_;
		}
		_tmp8_ = ns;
		_tmp9_ = _tmp8_->next;
		ns = _tmp9_;
	}
	_tmp10_ = dns;
	if (_tmp10_ != NULL) {
		xmlNs* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		gchar* _tmp13_ = NULL;
		_tmp11_ = dns;
		_tmp12_ = _tmp11_->href;
		_tmp13_ = g_strdup (_tmp12_);
		result = _tmp13_;
		return result;
	}
	result = NULL;
	return result;
}


static gchar* gxml_gelement_real_get_prefix (GXmlDomElement* base) {
	gchar* result;
	GXmlGElement* self;
	xmlNode* _tmp0_ = NULL;
	xmlNs* ns = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNs* _tmp2_ = NULL;
	xmlNs* dns = NULL;
	xmlNs* _tmp3_ = NULL;
	xmlNs* _tmp10_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = ((GXmlGNode*) self)->_node;
	if (_tmp0_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp1_ = ((GXmlGNode*) self)->_node;
	_tmp2_ = _tmp1_->nsDef;
	ns = _tmp2_;
	_tmp3_ = ns;
	dns = _tmp3_;
	while (TRUE) {
		xmlNs* _tmp4_ = NULL;
		xmlNs* _tmp5_ = NULL;
		const gchar* _tmp6_ = NULL;
		xmlNs* _tmp8_ = NULL;
		xmlNs* _tmp9_ = NULL;
		_tmp4_ = ns;
		if (!(_tmp4_ != NULL)) {
			break;
		}
		_tmp5_ = ns;
		_tmp6_ = _tmp5_->prefix;
		if (_tmp6_ == NULL) {
			xmlNs* _tmp7_ = NULL;
			_tmp7_ = ns;
			dns = _tmp7_;
		}
		_tmp8_ = ns;
		_tmp9_ = _tmp8_->next;
		ns = _tmp9_;
	}
	_tmp10_ = dns;
	if (_tmp10_ != NULL) {
		xmlNs* _tmp11_ = NULL;
		const gchar* _tmp12_ = NULL;
		_tmp11_ = dns;
		_tmp12_ = _tmp11_->prefix;
		if (_tmp12_ != NULL) {
			xmlNs* _tmp13_ = NULL;
			const gchar* _tmp14_ = NULL;
			gchar* _tmp15_ = NULL;
			_tmp13_ = dns;
			_tmp14_ = _tmp13_->prefix;
			_tmp15_ = g_strdup (_tmp14_);
			result = _tmp15_;
			return result;
		}
	}
	result = NULL;
	return result;
}


static gchar* gxml_gelement_real_get_local_name (GXmlDomElement* base) {
	gchar* result;
	GXmlGElement* self;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = gxml_gnode_get_name ((GXmlGNode*) self);
	_tmp1_ = _tmp0_;
	result = _tmp1_;
	return result;
}


static gchar* gxml_gelement_real_get_id (GXmlDomElement* base) {
	gchar* result;
	GXmlGElement* self;
	GXmlNode* p = NULL;
	GeeMap* _tmp0_ = NULL;
	GeeMap* _tmp1_ = NULL;
	GeeMap* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlNode* _tmp4_ = NULL;
	GXmlNode* _tmp5_ = NULL;
	GXmlNode* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = gxml_gnode_get_attrs ((GXmlGNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_map_get (_tmp2_, "id");
	_tmp4_ = (GXmlNode*) _tmp3_;
	_g_object_unref0 (_tmp2_);
	p = _tmp4_;
	_tmp5_ = p;
	if (_tmp5_ == NULL) {
		result = NULL;
		_g_object_unref0 (p);
		return result;
	}
	_tmp6_ = p;
	_tmp7_ = gxml_node_get_value (_tmp6_);
	_tmp8_ = _tmp7_;
	result = _tmp8_;
	_g_object_unref0 (p);
	return result;
}


static void gxml_gelement_real_set_id (GXmlDomElement* base, const gchar* value) {
	GXmlGElement* self;
	GXmlNode* p = NULL;
	GeeMap* _tmp0_ = NULL;
	GeeMap* _tmp1_ = NULL;
	GeeMap* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlNode* _tmp4_ = NULL;
	GXmlNode* _tmp5_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = gxml_gnode_get_attrs ((GXmlGNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_map_get (_tmp2_, "id");
	_tmp4_ = (GXmlNode*) _tmp3_;
	_g_object_unref0 (_tmp2_);
	p = _tmp4_;
	_tmp5_ = p;
	if (_tmp5_ == NULL) {
		const gchar* _tmp6_ = NULL;
		_tmp6_ = value;
		gxml_element_set_attr ((GXmlElement*) self, "id", _tmp6_);
	} else {
		GXmlNode* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		_tmp7_ = p;
		_tmp8_ = value;
		gxml_node_set_value (_tmp7_, _tmp8_);
	}
	_g_object_unref0 (p);
	g_object_notify ((GObject *) self, "id");
}


static gchar* gxml_gelement_real_get_class_name (GXmlDomElement* base) {
	gchar* result;
	GXmlGElement* self;
	GXmlNode* p = NULL;
	GeeMap* _tmp0_ = NULL;
	GeeMap* _tmp1_ = NULL;
	GeeMap* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlNode* _tmp4_ = NULL;
	GXmlNode* _tmp5_ = NULL;
	GXmlNode* _tmp6_ = NULL;
	gchar* _tmp7_ = NULL;
	gchar* _tmp8_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = gxml_gnode_get_attrs ((GXmlGNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_map_get (_tmp2_, "class");
	_tmp4_ = (GXmlNode*) _tmp3_;
	_g_object_unref0 (_tmp2_);
	p = _tmp4_;
	_tmp5_ = p;
	if (_tmp5_ == NULL) {
		result = NULL;
		_g_object_unref0 (p);
		return result;
	}
	_tmp6_ = p;
	_tmp7_ = gxml_node_get_value (_tmp6_);
	_tmp8_ = _tmp7_;
	result = _tmp8_;
	_g_object_unref0 (p);
	return result;
}


static void gxml_gelement_real_set_class_name (GXmlDomElement* base, const gchar* value) {
	GXmlGElement* self;
	GXmlNode* p = NULL;
	GeeMap* _tmp0_ = NULL;
	GeeMap* _tmp1_ = NULL;
	GeeMap* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlNode* _tmp4_ = NULL;
	GXmlNode* _tmp5_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = gxml_gnode_get_attrs ((GXmlGNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_map_get (_tmp2_, "class");
	_tmp4_ = (GXmlNode*) _tmp3_;
	_g_object_unref0 (_tmp2_);
	p = _tmp4_;
	_tmp5_ = p;
	if (_tmp5_ == NULL) {
		const gchar* _tmp6_ = NULL;
		_tmp6_ = value;
		gxml_element_set_attr ((GXmlElement*) self, "class", _tmp6_);
	} else {
		GXmlNode* _tmp7_ = NULL;
		const gchar* _tmp8_ = NULL;
		_tmp7_ = p;
		_tmp8_ = value;
		gxml_node_set_value (_tmp7_, _tmp8_);
	}
	_g_object_unref0 (p);
	g_object_notify ((GObject *) self, "class-name");
}


static GXmlDomTokenList* gxml_gelement_real_get_class_list (GXmlDomElement* base) {
	GXmlDomTokenList* result;
	GXmlGElement* self;
	GXmlGDomTokenList* _tmp0_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = gxml_gdom_token_list_new ((GXmlDomElement*) self, "class");
	result = (GXmlDomTokenList*) _tmp0_;
	return result;
}


static GXmlDomNamedNodeMap* gxml_gelement_real_get_attributes (GXmlDomElement* base) {
	GXmlDomNamedNodeMap* result;
	GXmlGElement* self;
	GeeMap* _tmp0_ = NULL;
	GeeMap* _tmp1_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = gxml_gnode_get_attrs ((GXmlGNode*) self);
	_tmp1_ = _tmp0_;
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp1_, GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap);
	return result;
}


static GXmlDomHTMLCollection* gxml_gelement_real_get_children (GXmlDomParentNode* base) {
	GXmlDomHTMLCollection* result;
	GXmlGElement* self;
	GXmlDomElementList* l = NULL;
	GXmlDomElementList* _tmp0_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = gxml_dom_element_list_new ();
	l = _tmp0_;
	{
		GXmlDomNodeList* _n_list = NULL;
		GXmlDomNodeList* _tmp1_ = NULL;
		GXmlDomNodeList* _tmp2_ = NULL;
		gint _n_size = 0;
		GXmlDomNodeList* _tmp3_ = NULL;
		gint _tmp4_ = 0;
		gint _tmp5_ = 0;
		gint _n_index = 0;
		_tmp1_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp2_ = _tmp1_;
		_n_list = _tmp2_;
		_tmp3_ = _n_list;
		_tmp4_ = gee_collection_get_size ((GeeCollection*) _tmp3_);
		_tmp5_ = _tmp4_;
		_n_size = _tmp5_;
		_n_index = -1;
		while (TRUE) {
			gint _tmp6_ = 0;
			gint _tmp7_ = 0;
			gint _tmp8_ = 0;
			GXmlDomNode* n = NULL;
			GXmlDomNodeList* _tmp9_ = NULL;
			gint _tmp10_ = 0;
			gpointer _tmp11_ = NULL;
			GXmlDomNode* _tmp12_ = NULL;
			_tmp6_ = _n_index;
			_n_index = _tmp6_ + 1;
			_tmp7_ = _n_index;
			_tmp8_ = _n_size;
			if (!(_tmp7_ < _tmp8_)) {
				break;
			}
			_tmp9_ = _n_list;
			_tmp10_ = _n_index;
			_tmp11_ = gee_list_get ((GeeList*) _tmp9_, _tmp10_);
			n = (GXmlDomNode*) _tmp11_;
			_tmp12_ = n;
			if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp12_, GXML_TYPE_DOM_ELEMENT)) {
				GXmlDomElementList* _tmp13_ = NULL;
				GXmlDomNode* _tmp14_ = NULL;
				_tmp13_ = l;
				_tmp14_ = n;
				gee_abstract_collection_add ((GeeAbstractCollection*) _tmp13_, G_TYPE_CHECK_INSTANCE_CAST (_tmp14_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement));
			}
			_g_object_unref0 (n);
		}
		_g_object_unref0 (_n_list);
	}
	result = (GXmlDomHTMLCollection*) l;
	return result;
}


static GXmlDomElement* gxml_gelement_real_get_first_element_child (GXmlDomParentNode* base) {
	GXmlDomElement* result;
	GXmlGElement* self;
	GXmlDomHTMLCollection* _tmp0_ = NULL;
	GXmlDomHTMLCollection* _tmp1_ = NULL;
	GXmlDomHTMLCollection* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlDomElement* _tmp4_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_first ((GeeList*) _tmp2_);
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomElement*) _tmp3_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
	_g_object_unref0 (_tmp2_);
	result = _tmp4_;
	return result;
}


static GXmlDomElement* gxml_gelement_real_get_last_element_child (GXmlDomParentNode* base) {
	GXmlDomElement* result;
	GXmlGElement* self;
	GXmlDomHTMLCollection* _tmp0_ = NULL;
	GXmlDomHTMLCollection* _tmp1_ = NULL;
	GXmlDomHTMLCollection* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlDomElement* _tmp4_ = NULL;
	self = (GXmlGElement*) base;
	_tmp0_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_last ((GeeList*) _tmp2_);
	_tmp4_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlDomElement*) _tmp3_, GXML_TYPE_DOM_ELEMENT, GXmlDomElement);
	_g_object_unref0 (_tmp2_);
	result = _tmp4_;
	return result;
}


static gint gxml_gelement_real_get_child_element_count (GXmlDomParentNode* base) {
	gint result;
	GXmlGElement* self;
	GXmlDomHTMLCollection* _tmp0_ = NULL;
	GXmlDomHTMLCollection* _tmp1_ = NULL;
	GXmlDomHTMLCollection* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	gint _tmp5_ = 0;
	self = (GXmlGElement*) base;
	_tmp0_ = gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_;
	_g_object_unref0 (_tmp2_);
	result = _tmp5_;
	return result;
}


static void gxml_gelement_class_init (GXmlGElementClass * klass) {
	gxml_gelement_parent_class = g_type_class_peek_parent (klass);
	((GXmlGNodeClass *) klass)->to_string = (gchar* (*)(GXmlGNode*)) gxml_gelement_real_to_string;
	GXML_GNODE_CLASS (klass)->get_value = gxml_gelement_real_get_value;
	GXML_GNODE_CLASS (klass)->set_value = gxml_gelement_real_set_value;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gelement_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gelement_set_property;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_CONTENT, g_param_spec_string ("content", "content", "content", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_TAG_NAME, g_param_spec_string ("tag-name", "tag-name", "tag-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_NAMESPACE_URI, g_param_spec_string ("namespace-uri", "namespace-uri", "namespace-uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_PREFIX, g_param_spec_string ("prefix", "prefix", "prefix", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_LOCAL_NAME, g_param_spec_string ("local-name", "local-name", "local-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_ID, g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_CLASS_NAME, g_param_spec_string ("class-name", "class-name", "class-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_CLASS_LIST, g_param_spec_object ("class-list", "class-list", "class-list", GXML_TYPE_DOM_TOKEN_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_ATTRIBUTES, g_param_spec_object ("attributes", "attributes", "attributes", GXML_TYPE_DOM_NAMED_NODE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_CHILDREN, g_param_spec_object ("children", "children", "children", GXML_TYPE_DOM_HTML_COLLECTION, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_FIRST_ELEMENT_CHILD, g_param_spec_object ("first-element-child", "first-element-child", "first-element-child", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_LAST_ELEMENT_CHILD, g_param_spec_object ("last-element-child", "last-element-child", "last-element-child", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GELEMENT_CHILD_ELEMENT_COUNT, g_param_spec_int ("child-element-count", "child-element-count", "child-element-count", G_MININT, G_MAXINT, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
}


static void gxml_gelement_gxml_dom_parent_node_interface_init (GXmlDomParentNodeIface * iface) {
	gxml_gelement_gxml_dom_parent_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->query_selector = (GXmlDomElement* (*)(GXmlDomParentNode*, const gchar*, GError**)) gxml_gelement_real_query_selector;
	iface->query_selector_all = (GXmlDomNodeList* (*)(GXmlDomParentNode*, const gchar*, GError**)) gxml_gelement_real_query_selector_all;
	iface->get_children = gxml_gelement_real_get_children;
	iface->get_first_element_child = gxml_gelement_real_get_first_element_child;
	iface->get_last_element_child = gxml_gelement_real_get_last_element_child;
	iface->get_child_element_count = gxml_gelement_real_get_child_element_count;
}


static void gxml_gelement_gxml_dom_element_interface_init (GXmlDomElementIface * iface) {
	gxml_gelement_gxml_dom_element_parent_iface = g_type_interface_peek_parent (iface);
	iface->get_attribute = (gchar* (*)(GXmlDomElement*, const gchar*)) gxml_gelement_real_get_attribute;
	iface->get_attribute_ns = (gchar* (*)(GXmlDomElement*, const gchar*, const gchar*)) gxml_gelement_real_get_attribute_ns;
	iface->set_attribute = (void (*)(GXmlDomElement*, const gchar*, const gchar*, GError**)) gxml_gelement_real_set_attribute;
	iface->set_attribute_ns = (void (*)(GXmlDomElement*, const gchar*, const gchar*, const gchar*, GError**)) gxml_gelement_real_set_attribute_ns;
	iface->remove_attribute = (void (*)(GXmlDomElement*, const gchar*)) gxml_gelement_real_remove_attribute;
	iface->remove_attribute_ns = (void (*)(GXmlDomElement*, const gchar*, const gchar*)) gxml_gelement_real_remove_attribute_ns;
	iface->has_attribute = (gboolean (*)(GXmlDomElement*, const gchar*)) gxml_gelement_real_has_attribute;
	iface->has_attribute_ns = (gboolean (*)(GXmlDomElement*, const gchar*, const gchar*)) gxml_gelement_real_has_attribute_ns;
	iface->get_elements_by_tag_name = (GXmlDomHTMLCollection* (*)(GXmlDomElement*, const gchar*)) gxml_gelement_real_get_elements_by_tag_name;
	iface->get_elements_by_tag_name_ns = (GXmlDomHTMLCollection* (*)(GXmlDomElement*, const gchar*, const gchar*)) gxml_gelement_real_get_elements_by_tag_name_ns;
	iface->get_elements_by_class_name = (GXmlDomHTMLCollection* (*)(GXmlDomElement*, const gchar*)) gxml_gelement_real_get_elements_by_class_name;
	iface->get_tag_name = gxml_gelement_real_get_tag_name;
	iface->get_namespace_uri = gxml_gelement_real_get_namespace_uri;
	iface->get_prefix = gxml_gelement_real_get_prefix;
	iface->get_local_name = gxml_gelement_real_get_local_name;
	iface->get_id = gxml_gelement_real_get_id;
	iface->set_id = gxml_gelement_real_set_id;
	iface->get_class_name = gxml_gelement_real_get_class_name;
	iface->set_class_name = gxml_gelement_real_set_class_name;
	iface->get_class_list = gxml_gelement_real_get_class_list;
	iface->get_attributes = gxml_gelement_real_get_attributes;
}


static void gxml_gelement_gxml_element_interface_init (GXmlElementIface * iface) {
	gxml_gelement_gxml_element_parent_iface = g_type_interface_peek_parent (iface);
	iface->set_attr = (void (*)(GXmlElement*, const gchar*, const gchar*)) gxml_gelement_real_set_attr;
	iface->get_attr = (GXmlNode* (*)(GXmlElement*, const gchar*)) gxml_gelement_real_get_attr;
	iface->set_ns_attr = (void (*)(GXmlElement*, const gchar*, const gchar*, const gchar*)) gxml_gelement_real_set_ns_attr;
	iface->get_ns_attr = (GXmlNode* (*)(GXmlElement*, const gchar*, const gchar*)) gxml_gelement_real_get_ns_attr;
	iface->normalize = (void (*)(GXmlElement*)) gxml_gelement_real_normalize;
	iface->remove_attr = (void (*)(GXmlElement*, const gchar*)) gxml_gelement_real_remove_attr;
	iface->remove_ns_attr = (void (*)(GXmlElement*, const gchar*, const gchar*)) gxml_gelement_real_remove_ns_attr;
	iface->get_content = gxml_gelement_real_get_content;
	iface->set_content = gxml_gelement_real_set_content;
}


static void gxml_gelement_gxml_xpath_context_interface_init (GXmlXPathContextIface * iface) {
	gxml_gelement_gxml_xpath_context_parent_iface = g_type_interface_peek_parent (iface);
	iface->evaluate = (GXmlXPathObject* (*)(GXmlXPathContext*, const gchar*, GeeList*, GError**)) gxml_gelement_real_evaluate;
}


static void gxml_gelement_instance_init (GXmlGElement * self) {
}


/**
 * Class implemeting {@link GXml.Element} interface, not tied to libxml-2.0 library.
 */
GType gxml_gelement_get_type (void) {
	static volatile gsize gxml_gelement_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gelement_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGElementClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gelement_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGElement), 0, (GInstanceInitFunc) gxml_gelement_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_parent_node_info = { (GInterfaceInitFunc) gxml_gelement_gxml_dom_parent_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_element_info = { (GInterfaceInitFunc) gxml_gelement_gxml_dom_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_element_info = { (GInterfaceInitFunc) gxml_gelement_gxml_element_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_xpath_context_info = { (GInterfaceInitFunc) gxml_gelement_gxml_xpath_context_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gelement_type_id;
		gxml_gelement_type_id = g_type_register_static (GXML_TYPE_GNON_DOCUMENT_CHILD_NODE, "GXmlGElement", &g_define_type_info, 0);
		g_type_add_interface_static (gxml_gelement_type_id, GXML_TYPE_DOM_PARENT_NODE, &gxml_dom_parent_node_info);
		g_type_add_interface_static (gxml_gelement_type_id, GXML_TYPE_DOM_ELEMENT, &gxml_dom_element_info);
		g_type_add_interface_static (gxml_gelement_type_id, GXML_TYPE_ELEMENT, &gxml_element_info);
		g_type_add_interface_static (gxml_gelement_type_id, GXML_TYPE_XPATH_CONTEXT, &gxml_xpath_context_info);
		g_once_init_leave (&gxml_gelement_type_id__volatile, gxml_gelement_type_id);
	}
	return gxml_gelement_type_id__volatile;
}


static void _vala_gxml_gelement_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGElement * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GELEMENT, GXmlGElement);
	switch (property_id) {
		case GXML_GELEMENT_VALUE:
		g_value_take_string (value, gxml_gnode_get_value ((GXmlGNode*) self));
		break;
		case GXML_GELEMENT_CONTENT:
		g_value_take_string (value, gxml_element_get_content ((GXmlElement*) self));
		break;
		case GXML_GELEMENT_TAG_NAME:
		g_value_take_string (value, gxml_dom_element_get_tag_name ((GXmlDomElement*) self));
		break;
		case GXML_GELEMENT_NAMESPACE_URI:
		g_value_take_string (value, gxml_dom_element_get_namespace_uri ((GXmlDomElement*) self));
		break;
		case GXML_GELEMENT_PREFIX:
		g_value_take_string (value, gxml_dom_element_get_prefix ((GXmlDomElement*) self));
		break;
		case GXML_GELEMENT_LOCAL_NAME:
		g_value_take_string (value, gxml_dom_element_get_local_name ((GXmlDomElement*) self));
		break;
		case GXML_GELEMENT_ID:
		g_value_take_string (value, gxml_dom_element_get_id ((GXmlDomElement*) self));
		break;
		case GXML_GELEMENT_CLASS_NAME:
		g_value_take_string (value, gxml_dom_element_get_class_name ((GXmlDomElement*) self));
		break;
		case GXML_GELEMENT_CLASS_LIST:
		g_value_take_object (value, gxml_dom_element_get_class_list ((GXmlDomElement*) self));
		break;
		case GXML_GELEMENT_ATTRIBUTES:
		g_value_take_object (value, gxml_dom_element_get_attributes ((GXmlDomElement*) self));
		break;
		case GXML_GELEMENT_CHILDREN:
		g_value_take_object (value, gxml_dom_parent_node_get_children ((GXmlDomParentNode*) self));
		break;
		case GXML_GELEMENT_FIRST_ELEMENT_CHILD:
		g_value_take_object (value, gxml_dom_parent_node_get_first_element_child ((GXmlDomParentNode*) self));
		break;
		case GXML_GELEMENT_LAST_ELEMENT_CHILD:
		g_value_take_object (value, gxml_dom_parent_node_get_last_element_child ((GXmlDomParentNode*) self));
		break;
		case GXML_GELEMENT_CHILD_ELEMENT_COUNT:
		g_value_set_int (value, gxml_dom_parent_node_get_child_element_count ((GXmlDomParentNode*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gelement_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGElement * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GELEMENT, GXmlGElement);
	switch (property_id) {
		case GXML_GELEMENT_VALUE:
		gxml_gnode_set_value ((GXmlGNode*) self, g_value_get_string (value));
		break;
		case GXML_GELEMENT_CONTENT:
		gxml_element_set_content ((GXmlElement*) self, g_value_get_string (value));
		break;
		case GXML_GELEMENT_ID:
		gxml_dom_element_set_id ((GXmlDomElement*) self, g_value_get_string (value));
		break;
		case GXML_GELEMENT_CLASS_NAME:
		gxml_dom_element_set_class_name ((GXmlDomElement*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	if ((array != NULL) && (destroy_func != NULL)) {
		int i;
		for (i = 0; i < array_length; i = i + 1) {
			if (((gpointer*) array)[i] != NULL) {
				destroy_func (((gpointer*) array)[i]);
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
	_vala_array_destroy (array, array_length, destroy_func);
	g_free (array);
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
	if (array) {
		while (((gpointer*) array)[length]) {
			length++;
		}
	}
	return length;
}



